@@ -4,7 +4,7 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -77,7 +77,7 @@ class __EXPORT Runable;
  * storing object specific "persistant" data that is presumed to persist
  * during the life of a given derived object.  When the object is
  * destroyed, all accumulated data is automatically purged.
- * 
+ *
  * There are a number of odd and specialized utility classes found in Common
  * C++.  The most common of these is the "MemPager" class.  This is basically
  * a class to enable page-grouped "cumulative" memory allocation; all
@@ -96,8 +96,7 @@ private:
 	size_t pagesize;
 	unsigned int pages;
 
-	struct _page
-	{
+	struct _page {
 		struct _page *next;
 		size_t used;
 	} *page;
@@ -194,8 +193,7 @@ public:
 class __EXPORT StackPager : protected MemPager
 {
 private:
-	typedef struct frame
-	{
+	typedef struct frame {
 		struct frame *next;
 		char data[1];
 	}	frame_t;
@@ -298,13 +296,13 @@ protected:
  * to "<code>/etc</code>" prefixed (on UNIX) directories and this is processed within the constructor. It
  * could refer to the <code>/config</code> prefix on QNX, or even, gasp, a "<code>C:\WINDOWS</code>". Hence, a keypath of
  * "<code>/bayonne.d/vmhost/smtp</code>" actually resolves to a "<code>/etc/bayonne.d/vmhost.conf</code>" and loads key
- * value pairs from the <code>[smtp]</code> section of that <code>.conf</code> file. 
+ * value pairs from the <code>[smtp]</code> section of that <code>.conf</code> file.
  *
  * Similarly, something like "<code>~bayonne/smtp</code>" path refers to a "<code>~/.bayonnerc</code>" and loads key pairs
- * from the <code>[smtp]</code> section. This coercion occurs before the name is passed to the open call. 
+ * from the <code>[smtp]</code> section. This coercion occurs before the name is passed to the open call.
  *
  * I actually use derived keydata based classes as global initialized objects, and they hence
- * automatically load and parse config file entries even before "main" has started. 
+ * automatically load and parse config file entries even before "main" has started.
  *
  * Keydata can hold multiple values for the same key pair.  This can
  * occur either from storing a "list" of data items in a config file,
@@ -312,7 +310,7 @@ protected:
  * <code>~/.confrc</code> segments) into a single object.  The keys are stored as
  * cumulative (read-only/replacable) config values under a hash index
  * system for quick retrieval.
- * 
+ *
  * Keydata can
  * also load a table of "initialization" values for keyword pairs that were
  * not found in the external file.
@@ -321,7 +319,7 @@ protected:
  * specific portion of a known config file and initialize it's values.  One
  * can then declare a global instance of these objects and have
  * configuration data initialized automatically as the executable is loaded.
- * 
+ *
  * Hence, if I have a "[paths]" section in a "<code>/etc/server.conf?</code>" file, I might
  * define something like:
  *
@@ -334,14 +332,14 @@ protected:
  *       static Keydata::Define *defvalues = {
  * 	  {"datafiles", "/var/server"},
  * 	  {NULL, NULL}};
- * 
+ *
  *       // override with [paths] from "~/.serverrc" if avail.
- * 
+ *
  *       load("~server/paths");
  *       load(defvalues);
  *     }
  * };
- * 
+ *
  * KeyPaths keypaths;
  * </pre></code>
  *
@@ -355,14 +353,12 @@ public:
 #pragma pack(1)
 #endif
 
-	struct Keyval
-	{
+	struct Keyval {
 		Keyval *next;
 		char val[1];
 	};
 
-	struct Keysym
-	{
+	struct Keysym {
 		Keysym *next;
 		Keyval *data;
 		const char **list;
@@ -370,8 +366,7 @@ public:
 		char sym[1];
 	};
 
-	struct Define
-	{
+	struct Define {
 		char *keyword;
 		char *value;
 	};
@@ -412,7 +407,7 @@ public:
 	 * default system values with user specific keyword values.
 	 *
 	 * @param keypath (filepath/section)
-	 */ 
+	 */
 	void load(const char *keypath);
 
 	/**
@@ -427,7 +422,7 @@ public:
 	 *
 	 * @param prefix
 	 * @param keypath (filepath/section)
-	 */ 
+	 */
 	void loadPrefix(const char *prefix, const char *keypath);
 
 	/**
@@ -450,7 +445,7 @@ public:
 	 * @param pairs list of NULL terminated default keyword/value pairs.
 	 */
 	void load(Define *pairs);
-	
+
 	/**
 	 * Create an empty key data object.
 	 */
@@ -470,7 +465,7 @@ public:
 	 * pathfile to parse.
 	 *
 	 * @param pairs of keyword values from a define list
-	 * @param keypath of optional file and section to load from 
+	 * @param keypath of optional file and section to load from
 	 */
 	Keydata(Define *pairs, const char *keypath = NULL);
 
@@ -559,7 +554,7 @@ public:
 	 * @param default if not set.
 	 * @return value of key.
 	 */
-	double getDouble(const char *key, double def = 0.); 
+	double getDouble(const char *key, double def = 0.);
 
 	/**
 	 * Get an index array of ALL keywords that are stored by the
@@ -628,7 +623,7 @@ public:
 
 /**
  * This class is used to create derived classes which are constructed
- * within a memory pager pool.  
+ * within a memory pager pool.
  *
  * @short create objects in a memory pager.
  * @author David Sugar <dyfet@ostel.com>
@@ -676,9 +671,7 @@ public:
 class __EXPORT Assoc
 {
 private:
-	class __EXPORT entry
-	{
-	public:
+	struct entry {
 		const char *id;
 		entry *next;
 		void *data;
@@ -725,7 +718,7 @@ public:
 	 * @param count limit before wait queuing.
 	 */
 	Runlist(unsigned count = 1);
-	
+
 	/**
 	 * Add a runable object to this runlist.  If the number of
 	 * entries running is below the limit, then add returns true
@@ -776,14 +769,14 @@ protected:
 	virtual void ready(void) = 0;
 
 public:
-	/** 
+	/**
 	 * Start the object against a run list.
 	 *
 	 * @return true if immediately available to run.
 	 * @param list to start under.
 	 */
 	bool starting(Runlist *list);
-	
+
 	/**
 	 * Stop the object, called when stopping or ready completes.
 	 * May also be used for a task that has not yet started to
