@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -89,13 +89,13 @@ typedef unsigned short tpport_t;
  * that occupies a specific port address (and may be bound to a specific
  * network interface) on the local machine.  The socket may also be
  * directly connected to a specific socket on a remote internet host.
- * 
+ *
  * This base class is not directly used, but is
  * provided to offer properties common to other Common C++ socket classes,
  * including the socket exception model and the ability to set socket
  * properties such as QoS, "sockopts" properties like Dont-Route
  * and Keep-Alive, etc.
- * 
+ *
  *
  * @author David Sugar <dyfet@ostel.com>
  * @short base class of all sockets.
@@ -103,8 +103,7 @@ typedef unsigned short tpport_t;
 class __EXPORT Socket
 {
 public:
-	enum Family
-	{
+	enum Family {
 #ifdef	CCXX_IPV6
 		IPV6 = AF_INET6,
 #endif
@@ -113,8 +112,7 @@ public:
 
 	typedef enum Family Family;
 
-	enum Error
-	{
+	enum Error {
 		errSuccess = 0,
 		errCreateFailed,
 		errCopyFailed,
@@ -148,8 +146,7 @@ public:
 
 	typedef enum Error Error;
 
-	enum Tos
-	{
+	enum Tos {
 		tosLowDelay = 0,
 		tosThroughput,
 		tosReliability,
@@ -158,8 +155,7 @@ public:
 	};
 	typedef enum Tos Tos;
 
-	enum Pending
-	{
+	enum Pending {
 		pendingInput,
 		pendingOutput,
 		pendingError
@@ -167,8 +163,7 @@ public:
 	typedef enum Pending Pending;
 
 protected:
-	enum State
-	{
+	enum State {
 		INITIAL,
 		AVAILABLE,
 		BOUND,
@@ -190,8 +185,7 @@ private:
 protected:
 	static Mutex mutex;
 
-	mutable struct
-	{
+	mutable struct {
 		bool thrown: 1;
 		bool broadcast: 1;
 		bool route: 1;
@@ -204,7 +198,7 @@ protected:
 	} flags;
 
 	/**
-	 * the actual socket descriptor, in Windows, unlike posix it 
+	 * the actual socket descriptor, in Windows, unlike posix it
 	 * *cannot* be used as an file descriptor
 	 * that way madness lies -- jfc
 	 */
@@ -229,7 +223,7 @@ protected:
 	 */
 	inline void error(char *err) const
 		{error(errExtended, err);};
-	
+
 	/**
 	 * This service is used to turn the error handler on or off for
 	 * "throwing" exceptions by manipulating the thrown flag.
@@ -280,7 +274,7 @@ protected:
 	Error receiveTimeout(timeout_t timer);
 
 	/**
-	 * Set the protocol stack network kernel send buffer size 
+	 * Set the protocol stack network kernel send buffer size
 	 * associated with the socket.
 	 *
 	 * @return errSuccess on success, or error.
@@ -288,17 +282,17 @@ protected:
 	 */
 	Error sendBuffer(unsigned size);
 
-        /**
-         * Set the protocol stack network kernel receive buffer size
+	/**
+	 * Set the protocol stack network kernel receive buffer size
 	 * associated with the socket.
-         * 
-         * @return errSuccess on success, or error. 
-         * @param size of buffer in bytes.
-         */
-        Error receiveBuffer(unsigned size);
+	 *
+	 * @return errSuccess on success, or error.
+	 * @param size of buffer in bytes.
+	 */
+	Error receiveBuffer(unsigned size);
 
 	/**
-	 * Set the total protocol stack network kernel buffer size 
+	 * Set the total protocol stack network kernel buffer size
 	 * for both send and receive together.
 	 *
 	 * @return errSuccess on success
@@ -394,7 +388,7 @@ protected:
 	 * and UNIX socket domain (AF_UNIX) under unix.  The socket type
 	 * (SOCK_STREAM, SOCK_DGRAM) and protocol may also be specified.
 	 * If the socket cannot be created, an exception is thrown.
-	 * 
+	 *
 	 * @param domain socket domain to use.
 	 * @param type base type and protocol family of the socket.
 	 * @param protocol specific protocol to apply.
@@ -405,7 +399,7 @@ protected:
 	 * A socket object may be created from a file descriptor when that
 	 * descriptor was created either through a socket() or accept()
 	 * call.  This constructor is mostly for internal use.
-	 * 
+	 *
 	 * @param fd file descriptor of an already existing socket.
 	 */
 	Socket(SOCKET fd);
@@ -416,10 +410,10 @@ protected:
 	Socket();
 
 	/**
-         * A socket can also be constructed from an already existing
-         * Socket object. On POSIX systems, the socket file descriptor
-         * is dup()'d. On Win32, DuplicateHandle() is used.
-	 * 
+	 * A socket can also be constructed from an already existing
+	 * Socket object. On POSIX systems, the socket file descriptor
+	 * is dup()'d. On Win32, DuplicateHandle() is used.
+	 *
 	 * @param source of existing socket to clone.
 	 */
 	Socket(const Socket &source);
@@ -435,28 +429,28 @@ protected:
 	 */
 	ssize_t readLine(char *buf, size_t len, timeout_t timeout = 0);
 
-        /**
-         * Read in a block of len bytes with specific separator.  Can
-         * be zero, or any other char.  If \\n or \\r, it's treated just
-         * like a readLine().  Otherwise it looks for the separator.
-         *
-         * @param buf pointer to byte allocation.
-         * @param len maximum length to read.
-         * @param separator separator for a particular ASCII character
-         * @param t timeout for pending data in milliseconds.
-         * @return number of bytes actually read.
-         */
-        virtual ssize_t readData(void * buf,size_t len,char separator=0,timeout_t t=0);
+	/**
+	 * Read in a block of len bytes with specific separator.  Can
+	 * be zero, or any other char.  If \\n or \\r, it's treated just
+	 * like a readLine().  Otherwise it looks for the separator.
+	 *
+	 * @param buf pointer to byte allocation.
+	 * @param len maximum length to read.
+	 * @param separator separator for a particular ASCII character
+	 * @param t timeout for pending data in milliseconds.
+	 * @return number of bytes actually read.
+	 */
+	virtual ssize_t readData(void * buf,size_t len,char separator=0,timeout_t t=0);
 
-        /**
-         * Write a block of len bytes to socket.
-         *
-         * @param buf pointer to byte allocation.
-         * @param len maximum length to write.
-         * @param t timeout for pending data in milliseconds.
-         * @return number of bytes actually read.
-         */
-        virtual ssize_t writeData(const void* buf,size_t len,timeout_t t=0);
+	/**
+	 * Write a block of len bytes to socket.
+	 *
+	 * @param buf pointer to byte allocation.
+	 * @param len maximum length to write.
+	 * @param t timeout for pending data in milliseconds.
+	 * @return number of bytes actually read.
+	 */
+	virtual ssize_t writeData(const void* buf,size_t len,timeout_t t=0);
 
 public:
 	/**
@@ -535,21 +529,21 @@ public:
 
 	/**
 	 * Perform NAT table lookup for this socket.
-	 * Used to allow an application to know the original ip:port 
-	 * pair the the client "thinks" it is connecting to. Used mostly 
+	 * Used to allow an application to know the original ip:port
+	 * pair the the client "thinks" it is connecting to. Used mostly
 	 * to transparently impersonate a remote server/service.
 	 *
-	 * On error, 0.0.0.0:0 is returned and one of the following error codes 
-	 * is set: errServiceUnavailable - if nat is not supported on the 
+	 * On error, 0.0.0.0:0 is returned and one of the following error codes
+	 * is set: errServiceUnavailable - if nat is not supported on the
 	 * current platform or if it was not compiled; errLookupFail - if the
-	 * nat syscall failed for some reason (extended error code); 
+	 * nat syscall failed for some reason (extended error code);
 	 * errSearchErr - if the socket does not have nat information (i.e.
 	 * is not nated).
-	 * 
-	 * NAT lookup is supported on NetFilter for ipv4 and ipv6 (Linux), 
+	 *
+	 * NAT lookup is supported on NetFilter for ipv4 and ipv6 (Linux),
 	 * IPFilter for ipv4 (Solaris, *BSD except OpenBSD, HP-UX, etc.) and
 	 * Packet Filter for ipv4 and ipv6 (OpenBSD).
-	 * When using IPFilter or Packet Filter, the first NAT lookup must be 
+	 * When using IPFilter or Packet Filter, the first NAT lookup must be
 	 * performed as root (the NAT device is read only for root and is opened
 	 * once, unless an error occurs). Permissions on the nat device may be
 	 * changed to solve this.
@@ -557,7 +551,7 @@ public:
 	 * \warning When using IPFilter and Packet Filter, application data model
 	 * must be the same as the running kernel (32/64 bits).
 	 *
-	 * @param port ptr to NATed port number on local host. 
+	 * @param port ptr to NATed port number on local host.
 	 * @return NATed host address that this socket is related to.
 	 */
 	IPV4Host getIPV4NAT(tpport_t *port = NULL) const;
@@ -576,7 +570,7 @@ public:
 	 * I do not believe this form of non-blocking socket I/O is supported
 	 * in winsock, though it provides an alternate asynchronous set of
 	 * socket services.
-	 * 
+	 *
 	 * @param immediate mode specify socket I/O call blocking mode.
 	 */
 	void setCompletion(bool immediate);
@@ -652,15 +646,15 @@ public:
 	/**
  	 * Often used by a "catch" to fetch the last error of a thrown
 	 * socket.
-	 * 
+	 *
 	 * @return error number of Error error.
  	 */
 	inline Error getErrorNumber(void) const {return errid;}
-	
+
 	/**
  	 * Often used by a "catch" to fetch the user set error string
 	 * of a thrown socket, but only if EXTENDED error codes are used.
-	 * 
+	 *
 	 * @return string for error message.
  	 */
 	inline const char *getErrorString(void) const {return errstr;}
@@ -687,20 +681,20 @@ public:
  * specific message to an entire subnet.  Please note that Streaming of
  * realtime data commonly use UDPDuplex related classes rather than
  * UDPSocket.
- * 
+ *
  * In addition to connected TCP sessions, Common C++ supports UDP sockets and
  * these also cover a range of functionality.  Like a TCPSocket, A UDPSocket
  * can be created bound to a specific network interface and/or port address,
- * though this is not required.  UDP sockets also are usually either 
+ * though this is not required.  UDP sockets also are usually either
  * connected or otherwise "associated" with a specific "peer" UDP socket.
  * Since UDP sockets operate through discreet packets, there are no streaming
  * operators used with UDP sockets.
- * 
+ *
  * In addition to the UDP "socket" class, there is a "UDPBroadcast" class.
  * The UDPBroadcast is a socket that is set to send messages to a subnet as a
  * whole rather than to an individual peer socket that it may be associated
  * with.
- * 
+ *
  * UDP sockets are often used for building "realtime" media  streaming
  * protocols and full duplex messaging services.  When used in this manner,
  * typically a pair of UDP sockets are used together; one socket is used to
@@ -708,8 +702,8 @@ public:
  * on a "peer" host.  This concept is represented through the Common C++
  * UDPDuplex object, which is a pair of sockets that communicate with another
  * UDPDuplex pair.
- * 
- * 
+ *
+ *
  * @author David Sugar <dyfet@ostel.com>
  * @short Unreliable Datagram Protocol sockets.
  */
@@ -721,14 +715,12 @@ private:
 
 protected:
 #ifdef	CCXX_IPV6
-	union
-	{
+	union {
 		struct sockaddr_in6 ipv6;
 		struct sockaddr_in ipv4;
 	}	peer;
 #else
-	union
-	{
+	union {
 		struct sockaddr_in ipv4;
 	}	peer;
 #endif
@@ -751,7 +743,7 @@ public:
 	 * and port address so that other UDP sockets on remote
 	 * machines (or the same host) may find and send UDP messages
 	 * to it.  On failure to bind, an exception is thrown.
-	 * 
+	 *
 	 * @param bind address to bind this socket to.
 	 * @param port number to bind this socket to.
 	 */
@@ -797,24 +789,24 @@ public:
 	void connect(const IPV6Host &host, tpport_t port);
 #endif
 
-        /**
-         * get the interface index for a named network device
-         *
-         * @param ethX is device name, like "eth0" or "eth1"
-         * @param InterfaceIndex is the index value returned by os
+	/**
+	 * get the interface index for a named network device
+	 *
+	 * @param ethX is device name, like "eth0" or "eth1"
+	 * @param InterfaceIndex is the index value returned by os
 	 * @todo Win32 and ipv6 specific implementation.
-         */
-        Socket::Error getInterfaceIndex(const char *ethX,int& InterfaceIndex);
+	 */
+	Socket::Error getInterfaceIndex(const char *ethX,int& InterfaceIndex);
 
-        /**
-         * join a multicast group on a particular interface
-         *
-         * @param ia is the multicast address to use
-         * @param InterfaceIndex is the index value returned by 
+	/**
+	 * join a multicast group on a particular interface
+	 *
+	 * @param ia is the multicast address to use
+	 * @param InterfaceIndex is the index value returned by
 	 * getInterfaceIndex
 	 * @todo Win32 and ipv6 specific implementation.
-         */
-        Socket::Error join(const IPV4Multicast &ia,int InterfaceIndex);
+	 */
+	Socket::Error join(const IPV4Multicast &ia,int InterfaceIndex);
 
 
 	/**
@@ -869,10 +861,10 @@ public:
 	void connect(const char *service);
 
 	/**
-         * Disassociate this socket from any host connection.  No data
-         * should be read or written until a connection is established.
-         */
-        Error disconnect(void);
+	 * Disassociate this socket from any host connection.  No data
+	 * should be read or written until a connection is established.
+	 */
+	Error disconnect(void);
 };
 
 
@@ -908,7 +900,7 @@ public:
 	 * @param port number to use.
 	 */
 	void setPeer(const IPV4Broadcast &subnet, tpport_t port);
-};	
+};
 
 /**
  * Representing half of a two-way UDP connection, the UDP transmitter
@@ -940,10 +932,10 @@ protected:
 	 * Create a UDP transmitter, bind it to a specific interface
 	 * and port address so that other UDP sockets on remote
 	 * machines (or the same host) may find and send UDP messages
-	 * to it, and associate it with a given port on a peer host.  
-         * On failure to bind, an exception is thrown.  This class is
+	 * to it, and associate it with a given port on a peer host.
+	 * On failure to bind, an exception is thrown.  This class is
 	 * only used to build the UDP Duplex.
-	 * 
+	 *
 	 * @param bind address to bind this socket to.
 	 * @param port number to bind this socket to.
 	 */
@@ -1068,7 +1060,7 @@ protected:
 	 * and port address so that other UDP sockets on remote
 	 * machines (or the same host) may find and send UDP messages
 	 * to it, and associate it with a given port on a peer host.
-         * On failure to bind, an exception is thrown.
+	 * On failure to bind, an exception is thrown.
 	 *
 	 * @param bind address to bind this socket to.
 	 * @param port number to bind this socket to.
@@ -1168,7 +1160,7 @@ class __EXPORT UDPDuplex : public UDPTransmit, public UDPReceive
 public:
 	/**
 	 * Create a UDP duplex as a pair of UDP simplex objects
-         * bound to alternating and interconnected port addresses.
+	 * bound to alternating and interconnected port addresses.
 	 *
 	 * @param bind address to bind this socket to.
 	 * @param port number to bind sender.
@@ -1207,7 +1199,7 @@ public:
  * sockets.  Both error recovery and flow control operate transparently
  * for a TCP socket connection.  The TCP socket base class is primary used
  * to bind a TCP "server" for accepting TCP streams.
- * 
+ *
  * An implicit and unique TCPSocket object exists in Common C++ to represent
  * a bound TCP socket acting as a "server" for receiving connection requests.
  * This class is not part of TCPStream because such objects normally perform
@@ -1216,13 +1208,13 @@ public:
  * The Common C++ TCPSocket offers a Peek method to examine where the next
  * pending connection is coming from, and a Reject method to flush the next
  * request from the queue without having to create a session.
- * 
+ *
  * The TCPSocket also supports a "OnAccept" method which can be called when a
  * TCPStream related object is created from a TCPSocket.  By creating a
  * TCPStream from a TCPSocket, an accept operation automatically occurs, and
  * the TCPSocket can then still reject the client connection through the
  * return status of it's OnAccept method.
- * 
+ *
  * @author David Sugar <dyfet@tycho.com>
  * @short bound server for TCP streams and sessions.
  */
@@ -1239,7 +1231,7 @@ public:
 	 * server can implement protocol specific rules to exclude the
 	 * remote socket from being accepted by returning false.  The
 	 * Peek method can also be used for this purpose.
-	 * 
+	 *
 	 * @return true if client should be accepted.
 	 * @param ia internet host address of the client.
 	 * @param port number of the client.
@@ -1264,7 +1256,7 @@ public:
 	 * and that has a backlog queue to listen for remote connection
 	 * requests.  If the server cannot be created, an exception is
 	 * thrown.
-	 * 
+	 *
 	 * @param bind local ip address or interface to use.
 	 * @param port number to bind socket under.
 	 * @param backlog size of connection request queue.
@@ -1273,7 +1265,7 @@ public:
 	TCPSocket(const IPV4Address &bind, tpport_t port, unsigned backlog = 5, unsigned mss = 536);
 
 	/**
-	 * Create a named tcp socket by service and/or interface id.  
+	 * Create a named tcp socket by service and/or interface id.
 	 * For IPV4 we use [host:]svc or [host/]svc for the string.
 	 * If we have getaddrinfo, we use that to obtain the addr to
 	 * bind for.
@@ -1283,7 +1275,7 @@ public:
 	 * @param mss maximum segment size for streaming buffers.
 	 */
 	TCPSocket(const char *name, unsigned backlog = 5, unsigned mss = 536);
-	
+
 	/**
 	 * Return address and port of next connection request.  This
 	 * can be used instead of OnAccept() to pre-evaluate connection
@@ -1326,7 +1318,7 @@ public:
  * ipv6 sockets.  Both error recovery and flow control operate transparently
  * for a TCP socket connection.  The TCP socket base class is primary used
  * to bind a TCP "server" for accepting TCP streams.
- * 
+ *
  * An implicit and unique TCPV6Socket object exists in Common C++ to represent
  * a bound ipv6 TCP socket acting as a "server" for receiving connection requests.
  * This class is not part of TCPStream because such objects normally perform
@@ -1335,13 +1327,13 @@ public:
  * The Common C++ TCPV6Socket offers a Peek method to examine where the next
  * pending connection is coming from, and a Reject method to flush the next
  * request from the queue without having to create a session.
- * 
+ *
  * The TCPV6Socket also supports a "OnAccept" method which can be called when a
  * TCPStream related object is created from a TCPSocket.  By creating a
  * TCPStream from a TCPV6Socket, an accept operation automatically occurs, and
  * the TCPV6Socket can then still reject the client connection through the
  * return status of it's OnAccept method.
- * 
+ *
  * @author David Sugar <dyfet@tycho.com>
  * @short bound server for TCP streams and sessions.
  */
@@ -1358,7 +1350,7 @@ public:
 	 * server can implement protocol specific rules to exclude the
 	 * remote socket from being accepted by returning false.  The
 	 * Peek method can also be used for this purpose.
-	 * 
+	 *
 	 * @return true if client should be accepted.
 	 * @param ia internet host address of the client.
 	 * @param port number of the client.
@@ -1380,7 +1372,7 @@ public:
 	 * and that has a backlog queue to listen for remote connection
 	 * requests.  If the server cannot be created, an exception is
 	 * thrown.
-	 * 
+	 *
 	 * @param bind local ip address or interface to use.
 	 * @param port number to bind socket under.
 	 * @param backlog size of connection request queue.
@@ -1399,7 +1391,7 @@ public:
 	 * @param mss maximum segment size of streaming buffers.
 	 */
 	TCPV6Socket(const char *name, unsigned backlog = 5, unsigned mss = 536);
-	
+
 	/**
 	 * Return address and port of next connection request.  This
 	 * can be used instead of OnAccept() to pre-evaluate connection
@@ -1440,9 +1432,9 @@ public:
 
 /*
 :\projects\libraries\cplusplus\commonc++\win32\socket.h(357) : warning C4275: non dll-interface class 'streambuf' used as base for dll-interface class 'TCPStream'
-        c:\program files\microsoft visual studio\vc98\include\streamb.h(69) : see declaration of 'streambuf'
+	c:\program files\microsoft visual studio\vc98\include\streamb.h(69) : see declaration of 'streambuf'
 c:\projects\libraries\cplusplus\commonc++\win32\socket.h(358) : warning C4275: non dll-interface class 'iostream' used as base for dll-interface class 'TCPStream'
-        c:\program files\microsoft visual studio\vc98\include\iostream.h(66) : see declaration of 'iostream'
+	c:\program files\microsoft visual studio\vc98\include\iostream.h(66) : see declaration of 'iostream'
 */
 
 #ifdef _MSC_VER
@@ -1454,7 +1446,7 @@ c:\projects\libraries\cplusplus\commonc++\win32\socket.h(358) : warning C4275: n
  * by TCP protocol servers for accepting client connections.  The TCP
  * stream is a C++ "stream" class, and can accept streaming of data to
  * and from other C++ objects using the << and >> operators.
- * 
+ *
  *  TCPStream itself can be formed either by connecting to a bound network
  *  address of a TCP server, or can be created when "accepting" a
  *  network connection from a TCP server.
@@ -1669,15 +1661,15 @@ public:
 	 */
 	bool isPending(Pending pend, timeout_t timeout = TIMEOUT_INF);
 
-        /**
-          * Examine contents of next waiting packet.
-          *
-          * @param buf pointer to packet buffer for contents.
-          * @param len of packet buffer.
-          * @return number of bytes examined.
-          */
-         inline ssize_t peek(void *buf, size_t len)
-                 {return _IORET64 ::recv(so, (char *)buf, _IOLEN64 len, MSG_PEEK);};
+	/**
+	  * Examine contents of next waiting packet.
+	  *
+	  * @param buf pointer to packet buffer for contents.
+	  * @param len of packet buffer.
+	  * @return number of bytes examined.
+	  */
+	 inline ssize_t peek(void *buf, size_t len)
+		 {return _IORET64 ::recv(so, (char *)buf, _IOLEN64 len, MSG_PEEK);};
 
 	/**
 	 * Return the size of the current stream buffering used.
@@ -1692,9 +1684,9 @@ public:
  * The TCP session is used to primarily to represent a client connection
  * that can be managed on a seperate thread.  The TCP session also supports
  * a non-blocking connection scheme which prevents blocking during the
- * constructor and moving the process of completing a connection into the 
+ * constructor and moving the process of completing a connection into the
  * thread that executes for the session.
- * 
+ *
  * @author David Sugar <dyfet@ostel.com>
  * @short Threaded streamable socket with non-blocking constructor.
  */
@@ -1711,7 +1703,7 @@ protected:
 	 * calls after the connection completes.  To implement the
 	 * session one must create a derived class which implements
 	 * run().
-	 * 
+	 *
 	 * @return 0 if successful, -1 if timed out.
 	 * @param timeout to wait for completion in milliseconds.
 	 */
@@ -1729,14 +1721,14 @@ public:
 	/**
 	 * Create a TCP socket that will be connected to a remote TCP
 	 * server and that will execute under it's own thread.
-	 * 
+	 *
 	 * @param host internet address of remote TCP server.
 	 * @param port number of remote server.
 	 * @param size of streaming buffer.
 	 * @param pri execution priority relative to parent.
 	 * @param stack allocation needed on some platforms.
 	 */
-	TCPSession(const IPV4Host &host, 
+	TCPSession(const IPV4Host &host,
 		tpport_t port, size_t size = 536, int pri = 0, size_t stack = 0);
 #ifdef	CCXX_IPV6
 	TCPSession(const IPV6Host &host,
@@ -1747,7 +1739,7 @@ public:
 	 * Create a TCP socket from a bound TCP server by accepting a pending
 	 * connection from that server and execute a thread for the accepted
 	 * connection.
-	 * 
+	 *
 	 * @param server tcp socket to accept a connection from.
 	 * @param pri execution priority relative to parent.
 	 * @param stack allocation needed on some platforms.
@@ -1767,11 +1759,11 @@ public:
 
 /**
  *  class init_WSA used to initalise windows sockets specfifc stuff : there is
- *  an MS - specific init sequence for Winsock 2 this class attempts to 
- *  initalise Winsock 2.2 - needed for non - blocking I/O. It will fall back 
- *  on 1.2 or lower if 2.0 or higher is not available,  but < 2.0 does not 
+ *  an MS - specific init sequence for Winsock 2 this class attempts to
+ *  initalise Winsock 2.2 - needed for non - blocking I/O. It will fall back
+ *  on 1.2 or lower if 2.0 or higher is not available,  but < 2.0 does not
  *  support non - blocking I/o
- *  TO DO : might be an idea to have a method that reports version of 
+ *  TO DO : might be an idea to have a method that reports version of
  *  Winsock in use or a predicate to test if non - blocking is OK -- JFC
  */
 class init_WSA
@@ -1861,8 +1853,8 @@ public:
 	virtual ~SimpleTCPStream();
 
 	/**
-	 * @brief Get the status of pending stream data. 
-	 * 
+	 * @brief Get the status of pending stream data.
+	 *
 	 * This method can be used to examine if input or output is waiting,
 	 * or if an error or disconnect has occured on the stream.
 	 * If a read buffer contains data then input is ready. If write buffer
@@ -1893,7 +1885,7 @@ public:
 	 *
 	 * <long-description>
 	 *
-	 * @param bytes A pointer to a buffer containing the bytes to write. 
+	 * @param bytes A pointer to a buffer containing the bytes to write.
 	 * @param length The number of bytes to write (exactly).
 	 * @param timeout Period to time out, in milleseconds.
 	 *
@@ -1923,7 +1915,7 @@ class __EXPORT SockException : public IOException
 {
 private:
 	Socket::Error _socketError;
-	
+
 public:
 	SockException(const String &str, Socket::Error socketError, long systemError = 0) :
 		IOException(str, systemError), _socketError(socketError) {};
