@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -86,14 +86,13 @@
 #endif
 
 #ifdef  MACOSX
-#define MISSING_LOCKF   
+#define MISSING_LOCKF
 #endif
 
 #ifndef	F_LOCK
 #define	MISSING_LOCKF
 
-enum
-{
+enum {
 	F_ULOCK = 1,
 	F_LOCK,
 	F_TLOCK,
@@ -103,7 +102,7 @@ enum
 #endif
 
 #endif // ndef WIN32
-		
+
 #if defined(_OSF_SOURCE) && defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE > 1
 #undef	LOCK_EX
 #undef	LOCK_SH
@@ -134,7 +133,7 @@ namespace ost {
 RandomFile::RandomFile(const char *name) : Mutex(name) {
 #ifdef WIN32
 	fd = INVALID_HANDLE_VALUE;
-	// immediate is not defined on Win32 
+	// immediate is not defined on Win32
 #else
 	fd = -1;
 	flags.immediate = false;
@@ -150,8 +149,7 @@ RandomFile::RandomFile(const RandomFile &rf) : Mutex() {
 	HANDLE pidHandle = GetCurrentProcess();
 	HANDLE dupHandle;
 
-	if(rf.fd != INVALID_HANDLE_VALUE)
-	{
+	if(rf.fd != INVALID_HANDLE_VALUE) {
 		if(!DuplicateHandle(pidHandle, rf.fd, pidHandle, &dupHandle, 0, FALSE, DUPLICATE_SAME_ACCESS))
 			fd = INVALID_HANDLE_VALUE;
 		else
@@ -166,13 +164,13 @@ RandomFile::RandomFile(const RandomFile &rf) : Mutex() {
 	else
 		fd = -1;
 
-#endif	
+#endif
 
 	flags = rf.flags;
 	flags.count = 0;
 
 	if(rf.pathname)
-		pathname = newString(rf.pathname);		
+		pathname = newString(rf.pathname);
 	else
 		pathname = NULL;
 }
@@ -195,24 +193,21 @@ File::Attr RandomFile::initialize(void)
 void RandomFile::final(void)
 {
 #ifdef WIN32
-	if(fd != INVALID_HANDLE_VALUE)
-	{
+	if(fd != INVALID_HANDLE_VALUE) {
 		CloseHandle(fd);
 		if(flags.temp && pathname)
 			DeleteFile(pathname);
 	}
 
 #else
-	if(fd > -1)
-	{
+	if(fd > -1) {
 		close(fd);
 		if(flags.temp && pathname)
 			remove(pathname);
 	}
 #endif
 
-	if(pathname)
-	{
+	if(pathname) {
 		delString(pathname);
 		pathname = NULL;
 	}
@@ -230,15 +225,13 @@ RandomFile::Error RandomFile::error(Error id, char *str)
 {
 	errstr = str;
 	errid = id;
-	if(!flags.thrown)
-	{
+	if(!flags.thrown) {
 		flags.thrown = true;
 #ifdef	CCXX_EXCEPTIONS
 		if(Thread::getException() == Thread::throwObject)
 			throw(this);
 #ifdef	COMMON_STD_EXCEPTION
-		else if(Thread::getException() == Thread::throwException)
-		{
+		else if(Thread::getException() == Thread::throwException) {
 			if(!str)
 				str = "";
 			throw FileException(str);
@@ -257,23 +250,21 @@ bool RandomFile::initial(void)
 	if(fd == INVALID_HANDLE_VALUE)
 #else
 	if(fd < 0)
-#endif		
+#endif
 		return false;
 
 	enterMutex();
 	init = flags.initial;
 	flags.initial = false;
 
-	if(!init)
-	{
+	if(!init) {
 		leaveMutex();
 		return false;
 	}
 
 #ifdef WIN32
 	Attr access = initialize();
-	if(access == attrInvalid)
-	{
+	if(access == attrInvalid) {
 		CloseHandle(fd);
 		if(pathname)
 			DeleteFile(pathname);
@@ -285,8 +276,7 @@ bool RandomFile::initial(void)
 
 #else
 	int mode = (int)initialize();
-	if(!mode)
-	{
+	if(!mode) {
 		close(fd);
 		fd = -1;
 		if(pathname)
@@ -297,7 +287,7 @@ bool RandomFile::initial(void)
 	}
 	fchmod(fd, mode);
 #endif
-	
+
 	leaveMutex();
 	return init;
 }
@@ -316,8 +306,7 @@ RandomFile::Error RandomFile::setCompletion(Complete mode)
 #else
 	flag &= ~O_NDELAY;
 #endif
-	switch(mode)
-	{
+	switch(mode) {
 	case completionImmediate:
 #ifdef O_SYNC
 		flag |= O_SYNC;
@@ -383,8 +372,7 @@ ThreadFile::~ThreadFile()
 {
 	final();
 	fcb_t *next;
-	while(first)
-	{
+	while(first) {
 		next = first->next;
 		delete first;
 		first = next;
@@ -406,8 +394,7 @@ ThreadFile::Error ThreadFile::open(const char *path)
 		final();
 
 
-	if(path != pathname)
-	{
+	if(path != pathname) {
 		if(pathname)
 			delString(pathname);
 		pathname = newString(path);
@@ -417,8 +404,7 @@ ThreadFile::Error ThreadFile::open(const char *path)
 
 #ifdef WIN32
 	fd = CreateFile(pathname, GENERIC_READ | GENERIC_WRITE, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
-	if(fd == INVALID_HANDLE_VALUE)
-	{
+	if(fd == INVALID_HANDLE_VALUE) {
 		flags.initial = true;
 		fd = CreateFile(pathname, GENERIC_READ | GENERIC_WRITE, 0, NULL, CREATE_NEW, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
 	}
@@ -427,8 +413,7 @@ ThreadFile::Error ThreadFile::open(const char *path)
 
 #else
 	fd = ::open(pathname, O_RDWR);
-	if(fd < 0)
-	{
+	if(fd < 0) {
 		flags.initial = true;
 		fd = ::open(pathname, O_CREAT | O_RDWR | O_TRUNC,
 			    (int)attrPrivate);
@@ -437,8 +422,7 @@ ThreadFile::Error ThreadFile::open(const char *path)
 		return error(errOpenFailed);
 
 #ifdef	LOCK_EX
-	if(flock(fd, LOCK_EX | LOCK_NB))
-	{
+	if(flock(fd, LOCK_EX | LOCK_NB)) {
 		close(fd);
 		fd = -1;
 		return error(errOpenInUse);
@@ -453,8 +437,7 @@ ThreadFile::fcb_t *ThreadFile::getFCB(void)
 {
 	fcb_t *fcb = (fcb_t *)state.getKey();
 
-	if(!fcb)
-	{
+	if(!fcb) {
 		fcb = new fcb_t;
 		fcb->next = first;
 		first = fcb;
@@ -492,8 +475,7 @@ ThreadFile::Error ThreadFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 	save = Thread::enterCancel();
 	SetFilePointer(fd, fcb->pos, NULL, FILE_BEGIN);
 	DWORD count;
-	if(!ReadFile(fd, fcb->address, fcb->len, &count, NULL))
-	{
+	if(!ReadFile(fd, fcb->address, fcb->len, &count, NULL)) {
 		Thread::exitCancel(save);
 		leaveMutex();
 		return errReadFailure;
@@ -521,8 +503,7 @@ ThreadFile::Error ThreadFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 	if(io > -1)
 		return errReadIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errReadInterrupted;
 	default:
@@ -556,8 +537,7 @@ ThreadFile::Error ThreadFile::update(caddr_t address, ccxx_size_t len, off_t pos
 	Thread::Cancel save = Thread::enterCancel();
 	SetFilePointer(fd, fcb->pos, NULL, FILE_BEGIN);
 	DWORD count;
-	if(!WriteFile(fd, fcb->address, fcb->len, &count, NULL))
-	{
+	if(!WriteFile(fd, fcb->address, fcb->len, &count, NULL)) {
 		Thread::exitCancel(save);
 		leaveMutex();
 		return errWriteFailure;
@@ -585,8 +565,7 @@ ThreadFile::Error ThreadFile::update(caddr_t address, ccxx_size_t len, off_t pos
 	if(io > -1)
 		return errWriteIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errWriteInterrupted;
 	default:
@@ -617,8 +596,7 @@ ThreadFile::Error ThreadFile::append(caddr_t address, ccxx_size_t len)
 	Thread::Cancel save = Thread::enterCancel();
 	fcb->pos = SetFilePointer(fd, 0l, NULL, FILE_END);
 	DWORD count;
-	if(!WriteFile(fd, fcb->address, fcb->len, &count, NULL))
-	{
+	if(!WriteFile(fd, fcb->address, fcb->len, &count, NULL)) {
 		Thread::exitCancel(save);
 		leaveMutex();
 		return errWriteFailure;
@@ -641,8 +619,7 @@ ThreadFile::Error ThreadFile::append(caddr_t address, ccxx_size_t len)
 	if(io > -1)
 		return errWriteIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errWriteInterrupted;
 	default:
@@ -672,8 +649,7 @@ bool ThreadFile::operator++(void)
 #endif
 	leaveMutex();
 
-	if(fcb->pos >= eof)
-	{
+	if(fcb->pos >= eof) {
 		fcb->pos = eof;
 		return true;
 	}
@@ -685,8 +661,7 @@ bool ThreadFile::operator--(void)
 	fcb_t *fcb = getFCB();
 
 	fcb->pos -= fcb->len;
-	if(fcb->pos <= 0)
-	{
+	if(fcb->pos <= 0) {
 		fcb->pos = 0;
 		return true;
 	}
@@ -721,8 +696,7 @@ SharedFile::Error SharedFile::open(const char *path)
 #endif
 		final();
 
-	if(path != pathname)
-	{
+	if(path != pathname) {
 		if(pathname)
 			delString(pathname);
 		pathname = newString(path);
@@ -732,8 +706,7 @@ SharedFile::Error SharedFile::open(const char *path)
 
 #ifdef WIN32
 	fd = CreateFile(pathname, GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
-	if(fd == INVALID_HANDLE_VALUE)
-	{
+	if(fd == INVALID_HANDLE_VALUE) {
 		flags.initial = true;
 		fd = CreateFile(pathname, GENERIC_READ | GENERIC_WRITE, FILE_SHARE_READ | FILE_SHARE_WRITE, NULL, CREATE_NEW, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
 	}
@@ -744,8 +717,7 @@ SharedFile::Error SharedFile::open(const char *path)
 
 #else
 	fd = ::open(pathname, O_RDWR);
-	if(fd < 0)
-	{
+	if(fd < 0) {
 		flags.initial = true;
 		fd = ::open(pathname, O_CREAT | O_RDWR | O_TRUNC,
 			    (int)attrPrivate);
@@ -754,8 +726,7 @@ SharedFile::Error SharedFile::open(const char *path)
 		return error(errOpenFailed);
 
 #ifdef	LOCK_SH
-	if(flock(fd, LOCK_SH | LOCK_NB))
-	{
+	if(flock(fd, LOCK_SH | LOCK_NB)) {
 		close(fd);
 		fd = -1;
 		return error(errOpenInUse);
@@ -793,8 +764,7 @@ SharedFile::Error SharedFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 	over.OffsetHigh = 0;
 	LockFileEx(fd, LOCKFILE_EXCLUSIVE_LOCK, 0, fcb.len, 0, &over);
 	DWORD count;
-	if(!ReadFile(fd, fcb.address, fcb.len, &count, NULL))
-	{
+	if(!ReadFile(fd, fcb.address, fcb.len, &count, NULL)) {
 		Thread::exitCancel(save);
 		leaveMutex();
 		return errReadFailure;
@@ -808,12 +778,11 @@ SharedFile::Error SharedFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 
 #else
 	lseek(fd, fcb.pos, SEEK_SET);
-	if(lockf(fd, F_LOCK, fcb.len))
-	{
+	if(lockf(fd, F_LOCK, fcb.len)) {
 		leaveMutex();
 		return errLockFailure;
 	}
-		
+
 	int io = ::read(fd, fcb.address, fcb.len);
 	leaveMutex();
 
@@ -823,8 +792,7 @@ SharedFile::Error SharedFile::fetch(caddr_t address, ccxx_size_t len, off_t pos)
 	if(io > -1)
 		return errReadIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errReadInterrupted;
 	default:
@@ -847,8 +815,7 @@ SharedFile::Error SharedFile::clear(ccxx_size_t len, off_t pos)
 		fcb.pos = pos;
 
 	lseek(fd, fcb.pos, SEEK_SET);
-	if(lockf(fd, F_ULOCK, fcb.len))
-	{
+	if(lockf(fd, F_ULOCK, fcb.len)) {
 		leaveMutex();
 		return errLockFailure;
 	}
@@ -859,7 +826,7 @@ SharedFile::Error SharedFile::clear(ccxx_size_t len, off_t pos)
 
 SharedFile::Error SharedFile::update(caddr_t address, ccxx_size_t len, off_t pos)
 {
-#ifdef WIN32	
+#ifdef WIN32
 	if(fd == INVALID_HANDLE_VALUE)
 #else
 	if(fd < 0)
@@ -884,8 +851,7 @@ SharedFile::Error SharedFile::update(caddr_t address, ccxx_size_t len, off_t pos
 	over.Offset = pos;
 	over.OffsetHigh = 0;
 	DWORD count;
-	if(!WriteFile(fd, fcb.address, fcb.len, &count, NULL))
-	{
+	if(!WriteFile(fd, fcb.address, fcb.len, &count, NULL)) {
 		SetFilePointer(fd, fcb.pos, NULL, FILE_CURRENT);
 		UnlockFileEx(fd, 0, len, 0, &over);
 		Thread::exitCancel(save);
@@ -904,8 +870,7 @@ SharedFile::Error SharedFile::update(caddr_t address, ccxx_size_t len, off_t pos
 #else
 	lseek(fd, fcb.pos, SEEK_SET);
 	int io = ::write(fd, fcb.address, fcb.len);
-	if(lockf(fd, F_ULOCK, fcb.len))
-	{
+	if(lockf(fd, F_ULOCK, fcb.len)) {
 		leaveMutex();
 		return errLockFailure;
 	}
@@ -917,8 +882,7 @@ SharedFile::Error SharedFile::update(caddr_t address, ccxx_size_t len, off_t pos
 	if(io > -1)
 		return errWriteIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errWriteInterrupted;
 	default:
@@ -954,8 +918,7 @@ SharedFile::Error SharedFile::append(caddr_t address, ccxx_size_t len)
 	LockFileEx(fd, LOCKFILE_EXCLUSIVE_LOCK, 0, 0x7fffffff, 0, &over);
 	fcb.pos = SetFilePointer(fd, 0l, NULL, FILE_END);
 	DWORD count;
-	if(!WriteFile(fd, fcb.address, fcb.len, &count, NULL))
-	{
+	if(!WriteFile(fd, fcb.address, fcb.len, &count, NULL)) {
 		SetFilePointer(fd, eof, NULL, FILE_CURRENT);
 		Thread::exitCancel(save);
 		UnlockFileEx(fd, 0, 0x7fffffff, 0, &over);
@@ -974,16 +937,14 @@ SharedFile::Error SharedFile::append(caddr_t address, ccxx_size_t len)
 
 #else
 	fcb.pos = lseek(fd, 0l, SEEK_END);
-	if(lockf(fd, F_LOCK, -1))
-	{
+	if(lockf(fd, F_LOCK, -1)) {
 		leaveMutex();
 		return errLockFailure;
 	}
 	fcb.pos = lseek(fd, 0l, SEEK_END);
 	int io = ::write(fd, fcb.address, fcb.len);
 	lseek(fd, fcb.pos, SEEK_SET);
-	if(lockf(fd, F_ULOCK, -1))
-	{
+	if(lockf(fd, F_ULOCK, -1)) {
 		leaveMutex();
 		return errLockFailure;
 	}
@@ -995,8 +956,7 @@ SharedFile::Error SharedFile::append(caddr_t address, ccxx_size_t len)
 	if(io > -1)
 		return errWriteIncomplete;
 
-	switch(errno)
-	{
+	switch(errno) {
 	case EINTR:
 		return errWriteInterrupted;
 	default:
@@ -1022,8 +982,7 @@ bool SharedFile::operator++(void)
 	eof = lseek(fd, 0l, SEEK_END);
 #endif
 
-	if(fcb.pos >= eof)
-	{
+	if(fcb.pos >= eof) {
 		fcb.pos = eof;
 		leaveMutex();
 		return true;
@@ -1036,8 +995,7 @@ bool SharedFile::operator--(void)
 {
 	enterMutex();
 	fcb.pos -= fcb.len;
-	if(fcb.pos <= 0)
-	{
+	if(fcb.pos <= 0) {
 		fcb.pos = 0;
 		leaveMutex();
 		return true;
@@ -1061,8 +1019,7 @@ size_t MappedFile::pageAligned(size_t size)
 static void makemapname(const char *source, char *target)
 {
 	unsigned count = 60;
-	while(*source && count--)
-	{
+	while(*source && count--) {
 		if(*source == '/' || *source == '\\')
 			*(target++) = '_';
 		else
@@ -1079,26 +1036,24 @@ RandomFile(fname)
 	map = INVALID_HANDLE_VALUE;
 	fcb.address = NULL;
 
-        switch(mode)
-        {
-        case accessReadOnly:
-                share = FILE_SHARE_READ;  
-                page = PAGE_READONLY;
-                prot = FILE_MAP_READ;
-                break;   
-        case accessWriteOnly:
-                share = FILE_SHARE_WRITE;
-                page = PAGE_WRITECOPY;
-                prot = FILE_MAP_COPY;
-                break;
-        case accessReadWrite:
-                share = FILE_SHARE_READ|FILE_SHARE_WRITE;
-                page = PAGE_READWRITE;
-                prot = FILE_MAP_WRITE;
-        }
-	fd = CreateFile(pathname, mode, share, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL); 
-	if(fd == INVALID_HANDLE_VALUE)
-	{
+	switch(mode) {
+		case accessReadOnly:
+		share = FILE_SHARE_READ;
+		page = PAGE_READONLY;
+		prot = FILE_MAP_READ;
+		break;
+		case accessWriteOnly:
+		share = FILE_SHARE_WRITE;
+		page = PAGE_WRITECOPY;
+		prot = FILE_MAP_COPY;
+		break;
+		case accessReadWrite:
+		share = FILE_SHARE_READ|FILE_SHARE_WRITE;
+		page = PAGE_READWRITE;
+		prot = FILE_MAP_WRITE;
+	}
+	fd = CreateFile(pathname, mode, share, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
+	if(fd == INVALID_HANDLE_VALUE) {
 		error(errOpenFailed);
 		return;
 	}
@@ -1122,8 +1077,7 @@ RandomFile(fname)
 	map = INVALID_HANDLE_VALUE;
 	fcb.address = NULL;
 
-	switch(mode)
-	{
+	switch(mode) {
 	case accessReadOnly:
 		share = FILE_SHARE_READ;
 		page = PAGE_READONLY;
@@ -1140,8 +1094,7 @@ RandomFile(fname)
 		prot = FILE_MAP_WRITE;
 	}
 	fd = CreateFile(pathname, mode, share, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
-	if(fd == INVALID_HANDLE_VALUE)
-	{
+	if(fd == INVALID_HANDLE_VALUE) {
 		error(errOpenFailed);
 		return;
 	}
@@ -1158,8 +1111,7 @@ RandomFile(fname)
 	map = INVALID_HANDLE_VALUE;
 	fcb.address = NULL;
 
-	switch(mode)
-	{
+	switch(mode) {
 	case accessReadOnly:
 		share = FILE_SHARE_READ;
 		page = PAGE_READONLY;
@@ -1176,15 +1128,13 @@ RandomFile(fname)
 		prot = FILE_MAP_WRITE;
 	}
 	fd = CreateFile(pathname, mode, share, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS, NULL);
-	if(fd == INVALID_HANDLE_VALUE)
-	{
+	if(fd == INVALID_HANDLE_VALUE) {
 		error(errOpenFailed);
 		return;
 	}
 	makemapname(fname, mapname);
 	map = CreateFileMapping(fd, NULL, page, 0, 0, mapname);
-	if(!map)
-	{
+	if(!map) {
 		error(errMapFailed);
 		return;
 	}
@@ -1197,8 +1147,7 @@ RandomFile(fname)
 
 MappedFile::~MappedFile()
 {
-	if(fcb.address)
-	{
+	if(fcb.address) {
 		unlock();
 		UnmapViewOfFile(fcb.address);
 	}
@@ -1219,8 +1168,7 @@ void MappedFile::sync(caddr_t address, size_t len)
 
 void MappedFile::release(caddr_t address, size_t len)
 {
-	if(fcb.address)
-	{
+	if(fcb.address) {
 		unlock();
 		UnmapViewOfFile(fcb.address);
 	}
@@ -1229,8 +1177,7 @@ void MappedFile::release(caddr_t address, size_t len)
 
 caddr_t MappedFile::fetch(off_t pos, size_t len)
 {
-	if(fcb.address)
-	{
+	if(fcb.address) {
 		unlock();
 		UnmapViewOfFile(fcb.address);
 	}
@@ -1282,14 +1229,12 @@ RandomFile(fname)
 		fd = ::open(pathname, O_CREAT | O_RDWR | O_TRUNC,
 			    (int)attrPrivate);
 
-	if(fd < 0)
-	{
+	if(fd < 0) {
 		error(errOpenFailed);
 		return;
 	}
 
-	switch(mode)
-	{
+	switch(mode) {
 	case O_RDONLY:
 		prot = PROT_READ;
 		break;
@@ -1306,14 +1251,12 @@ RandomFile(fname)
 {
 	fd = open(fname, (int)mode | O_CREAT, 0660);
 
-	if(fd < 0)
-	{
+	if(fd < 0) {
 		error(errOpenFailed);
 		return;
 	}
 
-	switch(mode)
-	{
+	switch(mode) {
 	case O_RDONLY:
 		prot = PROT_READ;
 		break;
@@ -1330,8 +1273,7 @@ RandomFile(fname)
 	fcb.len = size;
 	fcb.pos = 0;
 	leaveMutex();
-	if((caddr_t)(fcb.address) == (caddr_t)(MAP_FAILED))
-	{
+	if((caddr_t)(fcb.address) == (caddr_t)(MAP_FAILED)) {
 		close(fd);
 		fd = -1;
 		error(errMapFailed);
@@ -1342,14 +1284,12 @@ MappedFile::MappedFile(const char *fname, pos_t pos, size_t len, Access mode) :
 RandomFile(fname)
 {
 	fd = open(fname, (int)mode);
-	if(fd < 0)
-	{
+	if(fd < 0) {
 		error(errOpenFailed);
 		return;
 	}
 
-	switch(mode)
-	{
+	switch(mode) {
 	case O_RDONLY:
 		prot = PROT_READ;
 		break;
@@ -1366,8 +1306,7 @@ RandomFile(fname)
 	fcb.len = len;
 	fcb.pos = pos;
 	leaveMutex();
-	if((caddr_t)(fcb.address) == (caddr_t)(MAP_FAILED))
-	{
+	if((caddr_t)(fcb.address) == (caddr_t)(MAP_FAILED)) {
 		close(fd);
 		fd = -1;
 		error(errMapFailed);
@@ -1463,11 +1402,11 @@ void MappedFile::update(caddr_t address, size_t len)
 
 #ifdef	WIN32
 #ifndef	SECS_BETWEEN_EPOCHS
-#define	SECS_BETWEEN_EPOCHS 11644473600
+#define	SECS_BETWEEN_EPOCHS 11644473600LL
 #endif
 
 #ifndef	SECS_TO_100NS
-#define	SECS_TO_100NS	10000000
+#define	SECS_TO_100NS	10000000LL
 #endif
 #endif
 
@@ -1484,9 +1423,9 @@ time_t lastAccessed(const char *path)
 		ino.ftLastAccessTime.dwLowDateTime;
 
 	ts -= (SECS_BETWEEN_EPOCHS * SECS_TO_100NS);
-        ts /= SECS_TO_100NS;
+	ts /= SECS_TO_100NS;
 
-        return(time_t)ts;
+	return(time_t)ts;
 #else
 	struct stat ino;
 
@@ -1515,7 +1454,7 @@ time_t lastModified(const char *path)
 	return(time_t)ts;
 #else
 	struct stat ino;
-	
+
 	if(stat(path, &ino))
 		return 0;
 
@@ -1641,11 +1580,11 @@ bool canModify(const char *path)
 
 const char *File::getExtension(const char *path)
 {
-        const char *cp = strrchr(path, '\\');
-        if(!cp)
-                cp = strrchr(path, '/');
-        if(!cp)
-                cp = strrchr(path, ':');
+	const char *cp = strrchr(path, '\\');
+	if(!cp)
+		cp = strrchr(path, '/');
+	if(!cp)
+		cp = strrchr(path, ':');
 
 
 	if(cp)
@@ -1700,14 +1639,14 @@ char *File::getFilename(const char *path, char *buffer, size_t size)
 char *File::getDirname(const char *path, char *buffer, size_t size)
 {
 	size_t len;
-        const char *cp = strrchr(path, '\\');
+	const char *cp = strrchr(path, '\\');
 
 	snprintf(buffer, size, "%s", path);
 
-        if(!cp)
-                cp = strrchr(path, '/');
-        if(!cp)
-                cp = strrchr(path, ':');
+	if(!cp)
+		cp = strrchr(path, '/');
+	if(!cp)
+		cp = strrchr(path, ':');
 
 	if(!cp)
 		return buffer;
@@ -1742,21 +1681,21 @@ const char *File::getExtension(const char *path)
 
 char *File::getDirname(const char *path, char *buffer, size_t size)
 {
-        unsigned len;
-        const char *cp = strrchr(path, '/');
+	unsigned len;
+	const char *cp = strrchr(path, '/');
 
-        snprintf(buffer, size, "%s", path);
+	snprintf(buffer, size, "%s", path);
 
-        if(!cp)
-                return buffer;
+	if(!cp)
+		return buffer;
 
-        if(cp)
-                len = cp - path;
+	if(cp)
+		len = cp - path;
 
-        if(len >= size)
-                len = size - 1;
-        buffer[len] = 0;
-        return buffer;
+	if(len >= size)
+		len = size - 1;
+	buffer[len] = 0;
+	return buffer;
 }
 
 const char *File::getFilename(const char *path)
@@ -1802,12 +1741,12 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 #ifdef  WIN323
 static char *getFile(char *path)
 {
-        char *cp = strchr(path, '\\');
-        if(!cp)
-                cp = strchr(path, '/');
-        if(!cp)
-                cp = strchr(path, ':');
-        return cp;
+	char *cp = strchr(path, '\\');
+	if(!cp)
+		cp = strchr(path, '/');
+	if(!cp)
+		cp = strchr(path, ':');
+	return cp;
 }
 #else
 static char *getFile(char *path)
@@ -1844,10 +1783,8 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 		snprintf(left, size, "%s", path + 1);
 		left_len = strlen(left);
   	}
-	else
-	{
-		if(!Dir::getPrefix(buffer, size))
-		{
+	else {
+		if(!Dir::getPrefix(buffer, size)) {
 			snprintf(buffer, size, "%s", ".");
 			return NULL;
 		}
@@ -1859,8 +1796,7 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 	if(left_len >= size || buffer_len >= size)
 		return NULL;
 
-	while(left_len > 0)
-	{
+	while(left_len > 0) {
 #ifdef	HAVE_LSTAT
 		struct stat ino;
 #endif
@@ -1878,8 +1814,7 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 			memmove(left, s + 1, left_len + 1);
 
 		next_token[s - left] = 0;
-		if(buffer[buffer_len - 1] != '/')
-		{
+		if(buffer[buffer_len - 1] != '/') {
 			if(buffer_len +1 >= size)
 				return NULL;
 
@@ -1890,10 +1825,8 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 			continue;
 		else if(!strcmp(next_token, "."))
 			continue;
-		else if(!strcmp(next_token, ".."))
-		{
-			if(buffer_len > 1)
-			{
+		else if(!strcmp(next_token, "..")) {
+			if(buffer_len > 1) {
 				char *q;
 				buffer[buffer_len - 1] = 0;
 #ifdef	WIN32
@@ -1921,51 +1854,45 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 
 		continue;
 #else
-		if(lstat(buffer, &ino) < 0)
-		{
+		if(lstat(buffer, &ino) < 0) {
 			if(errno == ENOENT && !p)
 				return buffer;
 
 			return NULL;
 		}
 
-		if((ino.st_mode & S_IFLNK) == S_IFLNK)
-		{
-                	char symlink[size];
-                        int slen;
+		if((ino.st_mode & S_IFLNK) == S_IFLNK) {
+					char symlink[size];
+			int slen;
 
-                        if (symlinks++ > MAXSYMLINKS)
+			if (symlinks++ > MAXSYMLINKS)
 				return NULL;
 
-                        slen = readlink(buffer, symlink, size);
+			slen = readlink(buffer, symlink, size);
 
-                        if (slen < 0)
-                                return NULL;
-                        symlink[slen] = 0;
+			if (slen < 0)
+				return NULL;
+			symlink[slen] = 0;
 
-                        if (symlink[0] == '/') 
-			{
-                                buffer[1] = 0;
-                                buffer_len = 1;
-                        } else if (buffer_len > 1) 
-			{
-                                char *q;
+			if (symlink[0] == '/') {
+				buffer[1] = 0;
+				buffer_len = 1;
+				} else if (buffer_len > 1) {
+				char *q;
 
 				buffer[buffer_len - 1] = 0;
-                                q = strrchr(buffer, '/');
-                                *q = 0;
-                                buffer_len = q - buffer;
-                        }
-                        if (symlink[slen - 1] != '/' && p) 
-			{
-                                if (slen >= size)
+				q = strrchr(buffer, '/');
+				*q = 0;
+				buffer_len = q - buffer;
+				}
+			if (symlink[slen - 1] != '/' && p) {
+				if (slen >= size)
 					return NULL;
 
-                                symlink[slen] = '/';
-                                symlink[slen + 1] = 0;
-                        }
-                        if(p)
-			{
+				symlink[slen] = '/';
+				symlink[slen + 1] = 0;
+				}
+			if(p) {
 				snprintf(symlink, size, "%s", left);
 				left_len = strlen(symlink);
 			}
@@ -1979,16 +1906,16 @@ char *File::getRealpath(const char *path, char *buffer, size_t size)
 	}
 
 #ifdef	WIN32
-        if(buffer_len > 1 && buffer[buffer_len - 1] == '\\')
-                buffer[buffer_len - 1] = 0;
-        else if(buffer_len > 1 && buffer[buffer_len - 1] == '/')
-                buffer[buffer_len - 1] = 0;
+		if(buffer_len > 1 && buffer[buffer_len - 1] == '\\')
+		buffer[buffer_len - 1] = 0;
+		else if(buffer_len > 1 && buffer[buffer_len - 1] == '/')
+		buffer[buffer_len - 1] = 0;
 #else
 	if(buffer_len > 1 && buffer[buffer_len - 1] == '/')
 		buffer[buffer_len - 1] = 0;
 #endif
 	return buffer;
-}
+	}
 
 #endif
 
