@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -57,11 +57,11 @@ extern "C" {
 Semaphore::Semaphore(unsigned resource)
 {
 	pthread_mutexattr_t attr;
-        pthread_mutexattr_init(&attr);
-        pthread_mutex_init(&_mutex, &attr);
-        pthread_mutexattr_destroy(&attr);
-        if(pthread_cond_init(&_cond, NULL) && Thread::getException() == Thread::throwObject)
-                THROW(this);
+	pthread_mutexattr_init(&attr);
+	pthread_mutex_init(&_mutex, &attr);
+	pthread_mutexattr_destroy(&attr);
+	if(pthread_cond_init(&_cond, NULL) && Thread::getException() == Thread::throwObject)
+		THROW(this);
 
 	_count = resource;
 	_waiters = 0;
@@ -70,7 +70,7 @@ Semaphore::Semaphore(unsigned resource)
 Semaphore::~Semaphore()
 {
 	pthread_cond_destroy(&_cond);
-        pthread_mutex_destroy(&_mutex);
+	pthread_mutex_destroy(&_mutex);
 }
 
 bool Semaphore::wait(timeout_t timeout)
@@ -84,8 +84,7 @@ bool Semaphore::wait(timeout_t timeout)
 	if(_count)
 		goto exiting;
 
-	if(!timeout)
-	{
+	if(!timeout) {
 		while(_count == 0)
 			pthread_cond_wait(&_cond, &_mutex);
 		goto exiting;
@@ -130,7 +129,7 @@ int Semaphore::getValue(void)
 Semaphore::Semaphore(unsigned resource)
 {
 	semObject = ::CreateSemaphore((LPSECURITY_ATTRIBUTES)NULL, (LONG)resource, MAX_SEM_VALUE, (LPCTSTR)NULL);
-}	
+}
 
 Semaphore::~Semaphore()
 {
