@@ -4,7 +4,7 @@
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -13,15 +13,15 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -102,7 +102,7 @@ using std::ios;
 #define CRTSCTS (IHFLOW | OHFLOW)
 #endif
 
-#if defined(_THR_UNIXWARE) || defined(__hpux) || defined(_AIX)  
+#if defined(_THR_UNIXWARE) || defined(__hpux) || defined(_AIX)
 #include <sys/termiox.h>
 #define	CRTSCTS	(CTSXON | RTSXOFF)
 #endif
@@ -116,7 +116,7 @@ using std::ios;
 #endif
 #endif
 
-#if defined(CTSXON) && defined(RTSXOFF) && !defined(CRTSCTS) 
+#if defined(CTSXON) && defined(RTSXOFF) && !defined(CRTSCTS)
 #define	CRTSCTS (CTSXON | RTSXOFF)
 #endif
 
@@ -141,35 +141,34 @@ Serial::Serial(const char *fname)
 	}
 
 #ifdef	WIN32
-    COMMTIMEOUTS  CommTimeOuts ;
+	COMMTIMEOUTS  CommTimeOuts ;
 
-    GetCommTimeouts(dev, &CommTimeOuts);
+	GetCommTimeouts(dev, &CommTimeOuts);
 
 //    CommTimeOuts.ReadIntervalTimeout = MAXDWORD;
-    CommTimeOuts.ReadIntervalTimeout = 0;
+	CommTimeOuts.ReadIntervalTimeout = 0;
 
-    CommTimeOuts.ReadTotalTimeoutMultiplier = 0 ;
-    CommTimeOuts.ReadTotalTimeoutConstant = 0;
-    CommTimeOuts.WriteTotalTimeoutMultiplier = 0 ;
-    CommTimeOuts.WriteTotalTimeoutConstant = 1000;
+	CommTimeOuts.ReadTotalTimeoutMultiplier = 0 ;
+	CommTimeOuts.ReadTotalTimeoutConstant = 0;
+	CommTimeOuts.WriteTotalTimeoutMultiplier = 0 ;
+	CommTimeOuts.WriteTotalTimeoutConstant = 1000;
 
-    SetCommTimeouts(dev, &CommTimeOuts) ;
+	SetCommTimeouts(dev, &CommTimeOuts) ;
 
 #else
-	
-	if(!isatty(dev))
-	{
+
+	if(!isatty(dev)) {
 		Serial::close();
 		error(errOpenNoTty);
 		return;
 	}
 #endif
-}
+	}
 
 Serial::~Serial()
 {
 	endSerial();
-}
+	}
 
 void Serial::initConfig(void)
 {
@@ -181,31 +180,31 @@ void Serial::initConfig(void)
 	DCB * attr = (DCB *)current;
 	DCB * orig = (DCB *)original;
 
-    attr->DCBlength = sizeof(DCB);
-    orig->DCBlength = sizeof(DCB);
+	attr->DCBlength = sizeof(DCB);
+	orig->DCBlength = sizeof(DCB);
 
-    GetCommState(dev, orig);
-    GetCommState(dev, attr);
+	GetCommState(dev, orig);
+	GetCommState(dev, attr);
 
-    attr->DCBlength = sizeof(DCB);
-    attr->BaudRate = 1200;
-    attr->Parity = NOPARITY;
-    attr->ByteSize = 8;
+	attr->DCBlength = sizeof(DCB);
+	attr->BaudRate = 1200;
+	attr->Parity = NOPARITY;
+	attr->ByteSize = 8;
 
-    attr->XonChar = ASCII_XON;
-    attr->XoffChar = ASCII_XOFF;
-    attr->XonLim = 100;
-    attr->XoffLim = 100;
-    attr->fOutxDsrFlow = 0;
-    attr->fDtrControl = DTR_CONTROL_ENABLE;
-    attr->fOutxCtsFlow = 1;
-    attr->fRtsControl = RTS_CONTROL_ENABLE;
-    attr->fInX = attr->fOutX = 0;
+	attr->XonChar = ASCII_XON;
+	attr->XoffChar = ASCII_XOFF;
+	attr->XonLim = 100;
+	attr->XoffLim = 100;
+	attr->fOutxDsrFlow = 0;
+	attr->fDtrControl = DTR_CONTROL_ENABLE;
+	attr->fOutxCtsFlow = 1;
+	attr->fRtsControl = RTS_CONTROL_ENABLE;
+	attr->fInX = attr->fOutX = 0;
 
-    attr->fBinary = true;
-    attr->fParity = true;
+	attr->fBinary = true;
+	attr->fParity = true;
 
-    SetCommState(dev, attr);
+	SetCommState(dev, attr);
 
 #else
 	struct termios *attr = (struct termios *)current;
@@ -221,13 +220,13 @@ void Serial::initConfig(void)
 
 	memset(attr->c_cc, 0, sizeof(attr->c_cc));
 	attr->c_cc[VMIN] = 1;
-	
+
 	// inherit original settings, maybe we should keep more??
 	cfsetispeed(attr, cfgetispeed(orig));
 	cfsetospeed(attr, cfgetospeed(orig));
 	attr->c_cflag |= orig->c_cflag & (CRTSCTS | CSIZE | PARENB | PARODD | CSTOPB);
 	attr->c_iflag |= orig->c_iflag & (IXON | IXANY | IXOFF);
-	
+
 	tcsetattr(dev, TCSANOW, attr);
 	fcntl(dev, F_SETFL, ioflags & ~O_NDELAY);
 
@@ -236,14 +235,14 @@ void Serial::initConfig(void)
 	ioctl(dev, TIOCMODG, &mcs);
 	mcs |= TIOCM_RTS;
 	ioctl(dev, TIOCMODS, &mcs);
-#endif	
+#endif
 
 #ifdef	_COHERENT
 	ioctl(dev, TIOCSRTS, 0);
 #endif
 
 #endif	// WIN32
-}
+	}
 
 void Serial::restore(void)
 {
@@ -254,7 +253,7 @@ void Serial::restore(void)
 	memcpy(current, original, sizeof(struct termios));
 	tcsetattr(dev, TCSANOW, (struct termios *)current);
 #endif
-}
+	}
 
 void Serial::initSerial(void)
 {
@@ -271,7 +270,7 @@ void Serial::initSerial(void)
 	current = new struct termios;
 	original = new struct termios;
 #endif
-}
+	}
 
 void Serial::endSerial(void)
 {
@@ -299,7 +298,7 @@ void Serial::endSerial(void)
 	current = NULL;
 	original = NULL;
 
-}
+	}
 
 Serial::Error Serial::error(Error err, char *errs)
 {
@@ -310,24 +309,23 @@ Serial::Error Serial::error(Error err, char *errs)
 
 	if(flags.thrown)
 		return err;
- 
+
 	// prevents recursive throws
- 
+
 	flags.thrown = true;
 #ifdef	CCXX_EXCEPTIONS
 	if(Thread::getException() == Thread::throwObject)
 	        throw((Serial *)this);
 #ifdef	COMMON_STD_EXCEPTION
-	else if(Thread::getException() == Thread::throwException)
-	{
+	else if(Thread::getException() == Thread::throwException) {
 		if(!errs)
 			errs = "";
 		throw SerException(String(errs));
 	}
 #endif
 #endif
-	return err;                                                             
-}
+	return err;
+	}
 
 int Serial::setPacketInput(int size, unsigned char btimer)
 {
@@ -354,7 +352,7 @@ int Serial::setPacketInput(int size, unsigned char btimer)
 	bufsize = size;
 	return size;
 #endif
-}
+	}
 
 int Serial::setLineInput(char newline, char nl1)
 {
@@ -377,7 +375,7 @@ int Serial::setLineInput(char newline, char nl1)
 	return bufsize;
 #endif
 
-}
+	}
 
 void Serial::flushInput(void)
 {
@@ -386,7 +384,7 @@ void Serial::flushInput(void)
 #else
 	tcflush(dev, TCIFLUSH);
 #endif
-}
+	}
 
 void Serial::flushOutput(void)
 {
@@ -395,7 +393,7 @@ void Serial::flushOutput(void)
 #else
 	tcflush(dev, TCOFLUSH);
 #endif
-}
+	}
 
 void Serial::waitOutput(void)
 {
@@ -404,7 +402,7 @@ void Serial::waitOutput(void)
 #else
 	tcdrain(dev);
 #endif
-}
+	}
 
 Serial &Serial::operator=(const Serial &ser)
 {
@@ -418,8 +416,7 @@ Serial &Serial::operator=(const Serial &ser)
 
 	int result = DuplicateHandle(process, ser.dev, process, &dev, DUPLICATE_SAME_ACCESS, 0, 0);
 
-	if (0 == result)
-	{
+	if (0 == result) {
 		memcpy(current, ser.current, sizeof(DCB));
 		memcpy(original, ser.original, sizeof(DCB));
 	}
@@ -430,7 +427,7 @@ Serial &Serial::operator=(const Serial &ser)
 	memcpy(original, ser.original, sizeof(struct termios));
 #endif
 	return *this;
-}
+	}
 
 
 void Serial::open(const char * fname)
@@ -442,18 +439,18 @@ void Serial::open(const char * fname)
 	if(dev > -1)
 		initConfig();
 #else
-    // open COMM device
-    dev = CreateFile(fname,
-                    GENERIC_READ | GENERIC_WRITE,
-                    0,                    // exclusive access
-                    NULL,                 // no security attrs
-                    OPEN_EXISTING,
-                    FILE_FLAG_OVERLAPPED | FILE_ATTRIBUTE_NORMAL | FILE_FLAG_WRITE_THROUGH | FILE_FLAG_NO_BUFFERING,
-                    NULL);
+	// open COMM device
+	dev = CreateFile(fname,
+		GENERIC_READ | GENERIC_WRITE,
+		0,                    // exclusive access
+		NULL,                 // no security attrs
+		OPEN_EXISTING,
+		FILE_FLAG_OVERLAPPED | FILE_ATTRIBUTE_NORMAL | FILE_FLAG_WRITE_THROUGH | FILE_FLAG_NO_BUFFERING,
+		NULL);
 	if(dev != INVALID_HANDLE_VALUE)
 		initConfig();
 #endif
-}
+	}
 
 #ifdef	WIN32
 int Serial::aRead(char * Data, const int Length)
@@ -461,84 +458,79 @@ int Serial::aRead(char * Data, const int Length)
 
 	unsigned long	dwLength = 0, dwError, dwReadLength;
 	COMSTAT	cs;
-    OVERLAPPED ol;
-    
-    // Return zero if handle is invalid
-    if(dev == INVALID_HANDLE_VALUE)
-        return 0;
+	OVERLAPPED ol;
 
-    // Read max length or only what is available
-    ClearCommError(dev, &dwError, &cs);
+	// Return zero if handle is invalid
+	if(dev == INVALID_HANDLE_VALUE)
+		return 0;
 
-    // If not requiring an exact byte count, get whatever is available
-    if(Length > (int)cs.cbInQue)
-        dwReadLength = cs.cbInQue;
-    else
-        dwReadLength = Length;
+	// Read max length or only what is available
+	ClearCommError(dev, &dwError, &cs);
+
+	// If not requiring an exact byte count, get whatever is available
+	if(Length > (int)cs.cbInQue)
+		dwReadLength = cs.cbInQue;
+	else
+		dwReadLength = Length;
+
+	memset(&ol, 0, sizeof(OVERLAPPED));
+	ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
+
+	if(dwReadLength > 0) {
+		if(ReadFile(dev, Data, dwReadLength, &dwLength, &ol) == FALSE) {
+			if(GetLastError() == ERROR_IO_PENDING) {
+				WaitForSingleObject(ol.hEvent, INFINITE);
+				GetOverlappedResult(dev, &ol, &dwLength, TRUE);
+				}
+			else
+				ClearCommError(dev, &dwError, &cs);
+			}
+		}
+
+	if(ol.hEvent != INVALID_HANDLE_VALUE)
+		CloseHandle(ol.hEvent);
 
-    memset(&ol, 0, sizeof(OVERLAPPED));
-    ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
-    
-    if(dwReadLength > 0)
-    {
-        if(ReadFile(dev, Data, dwReadLength, &dwLength, &ol) == FALSE) 
-        {
-            if(GetLastError() == ERROR_IO_PENDING)
-            {
-                WaitForSingleObject(ol.hEvent, INFINITE);
-                GetOverlappedResult(dev, &ol, &dwLength, TRUE);
-            }
-            else
-                ClearCommError(dev, &dwError, &cs);
-        }
-    }
-        
-    if(ol.hEvent != INVALID_HANDLE_VALUE)
-        CloseHandle(ol.hEvent);
-        
 	return dwLength;
-}
+	}
 
 int Serial::aWrite(const char * Data, const int Length)
 {
 	COMSTAT	cs;
 	unsigned long dwError = 0;
-    OVERLAPPED ol;
+	OVERLAPPED ol;
 
 	// Clear the com port of any error condition prior to read
 	ClearCommError(dev, &dwError, &cs);
 
 	unsigned long retSize = 0;
-    
-    memset(&ol, 0, sizeof(OVERLAPPED));
-    ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
-	
-    if(WriteFile(dev, Data, Length, &retSize, &ol) == FALSE)
-    {
-        if(GetLastError() == ERROR_IO_PENDING)
-        {
-            WaitForSingleObject(ol.hEvent, INFINITE);
-            GetOverlappedResult(dev, &ol, &retSize, TRUE);
-        }
-        else
-            ClearCommError(dev, &dwError, &cs);
-    }
-    
-    if(ol.hEvent != INVALID_HANDLE_VALUE)
-        CloseHandle(ol.hEvent);
-        
+
+	memset(&ol, 0, sizeof(OVERLAPPED));
+	ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
+
+	if(WriteFile(dev, Data, Length, &retSize, &ol) == FALSE) {
+		if(GetLastError() == ERROR_IO_PENDING) {
+			WaitForSingleObject(ol.hEvent, INFINITE);
+			GetOverlappedResult(dev, &ol, &retSize, TRUE);
+			}
+		else
+			ClearCommError(dev, &dwError, &cs);
+		}
+
+	if(ol.hEvent != INVALID_HANDLE_VALUE)
+		CloseHandle(ol.hEvent);
+
 	return retSize;
-}
+	}
 #else
 int Serial::aRead(char *Data, const int Length)
 {
 	return ::read(dev, Data, Length);
-}
+	}
 
 int Serial::aWrite(const char *Data, const int Length)
 {
 	return ::write(dev, Data, Length);
-}
+	}
 #endif
 
 void Serial::close()
@@ -549,8 +541,8 @@ void Serial::close()
 	::close(dev);
 #endif
 
-	dev = INVALID_HANDLE_VALUE;	
-}
+	dev = INVALID_HANDLE_VALUE;
+	}
 
 
 
@@ -578,109 +570,108 @@ void Serial::close()
 /*
 const int iAsync::getTimeOuts(unsigned long & readTimeout, unsigned long & writeTimeout)
 {
-    return GetCommTimeouts(_TheHandle, &CommTimeOuts);
-}
+	return GetCommTimeouts(_TheHandle, &CommTimeOuts);
+	}
 
 const int iAsync::setTimeOuts(unsigned long readTimeout, unsigned long writeTimeout)
 {
-    COMMTIMEOUTS  CommTimeOuts ;
+	COMMTIMEOUTS  CommTimeOuts ;
 
-    getTimeOuts(CommTimeOuts);
+	getTimeOuts(CommTimeOuts);
 
-    CommTimeOuts.ReadIntervalTimeout = readTimeout;
-    CommTimeOuts.ReadTotalTimeoutMultiplier = 0 ;
-    CommTimeOuts.ReadTotalTimeoutConstant = 0;
-    CommTimeOuts.WriteTotalTimeoutMultiplier = 0 ;
-    CommTimeOuts.WriteTotalTimeoutConstant = 1000;
+	CommTimeOuts.ReadIntervalTimeout = readTimeout;
+	CommTimeOuts.ReadTotalTimeoutMultiplier = 0 ;
+	CommTimeOuts.ReadTotalTimeoutConstant = 0;
+	CommTimeOuts.WriteTotalTimeoutMultiplier = 0 ;
+	CommTimeOuts.WriteTotalTimeoutConstant = 1000;
 
-    return GetCommTimeouts(_TheHandle, &CommTimeOuts);
-}
-    return SetCommTimeouts(_TheHandle, &CommTimeOuts) ;
+	return GetCommTimeouts(_TheHandle, &CommTimeOuts);
+	}
+	return SetCommTimeouts(_TheHandle, &CommTimeOuts) ;
 {
-    DCB        dcb ;
+	DCB        dcb ;
 
-    dcb.DCBlength = sizeof(DCB) ;
+	dcb.DCBlength = sizeof(DCB) ;
 
-    GetCommState(_TheHandle, &dcb) ;
+	GetCommState(_TheHandle, &dcb) ;
 
 	// hardcode this stuff for now.....
-    dcb.BaudRate = _TheBaudrate;
-    dcb.ByteSize = 8;
-    dcb.Parity   = NOPARITY;
-    dcb.StopBits = ONESTOPBIT;
-    dcb.fOutxDsrFlow = 0;
-    dcb.fDtrControl = DTR_CONTROL_ENABLE ;
-    dcb.fOutxCtsFlow = 1;
-    dcb.fRtsControl = RTS_CONTROL_HANDSHAKE ;
-    dcb.fInX = dcb.fOutX = 0;
+	dcb.BaudRate = _TheBaudrate;
+	dcb.ByteSize = 8;
+	dcb.Parity   = NOPARITY;
+	dcb.StopBits = ONESTOPBIT;
+	dcb.fOutxDsrFlow = 0;
+	dcb.fDtrControl = DTR_CONTROL_ENABLE ;
+	dcb.fOutxCtsFlow = 1;
+	dcb.fRtsControl = RTS_CONTROL_HANDSHAKE ;
+	dcb.fInX = dcb.fOutX = 0;
 
-    dcb.XonChar = ASCII_XON;
-    dcb.XoffChar = ASCII_XOFF;
-    dcb.XonLim = 100;
-    dcb.XoffLim = 100;
+	dcb.XonChar = ASCII_XON;
+	dcb.XoffChar = ASCII_XOFF;
+	dcb.XonLim = 100;
+	dcb.XoffLim = 100;
 
-    // other various settings
+	// other various settings
 
-    dcb.fBinary = TRUE;
-    dcb.fParity = TRUE;
+	dcb.fBinary = TRUE;
+	dcb.fParity = TRUE;
 
-    GetCommState(_TheHandle, &dcb) ;
-    dcb.DCBlength = sizeof(DCB) ;
-    dcb.BaudRate = _TheBaudrate;
-    SetCommState(_TheHandle, &dcb) ;
+	GetCommState(_TheHandle, &dcb) ;
+	dcb.DCBlength = sizeof(DCB) ;
+	dcb.BaudRate = _TheBaudrate;
+	SetCommState(_TheHandle, &dcb) ;
 
-}
+	}
 */
 
 Serial::Error Serial::setSpeed(unsigned long speed)
 {
 	unsigned long rate;
 
-	switch(speed)
-        {
+	switch(speed) {
 #ifdef B115200
-        case 115200: 
-                rate = B115200;
-                break; 
+		case 115200:
+				rate = B115200;
+				break;
 #endif
 #ifdef B57600
-        case 57600: 
-                rate = B57600;
-                break; 
+		case 57600:
+				rate = B57600;
+				break;
 #endif
 #ifdef B38400
-        case 38400: 
-                rate = B38400;
-                break; 
+		case 38400:
+				rate = B38400;
+				break;
 #endif
-        case 19200:
-                rate = B19200;
-                break;
-        case 9600:
-                rate = B9600;
-                break;
-        case 4800:
-                rate = B4800;
-                break;                                                          
-        case 2400:
-                rate = B2400;
-                break;
-        case 1200:
-                rate = B1200;
-                break;
-        case 600:
-                rate = B600;
-                break;
-        case 300:
-                rate = B300;
-                break;
-        case 110:
-                rate = B110;
-                break;
+		case 19200:
+				rate = B19200;
+				break;
+		case 9600:
+				rate = B9600;
+				break;
+		case 4800:
+				rate = B4800;
+				break;
+		case 2400:
+				rate = B2400;
+				break;
+		case 1200:
+				rate = B1200;
+				break;
+		case 600:
+				rate = B600;
+				break;
+		case 300:
+				rate = B300;
+				break;
+		case 110:
+				rate = B110;
+				break;
 #ifdef	B0
-        case 0:
-                rate = B0;
-                break;
+		case 0:
+				rate = B0;
+				break;
 #endif
 	default:
 		return error(errSpeedInvalid);
@@ -689,11 +680,11 @@ Serial::Error Serial::setSpeed(unsigned long speed)
 #ifdef	WIN32
 
 	DCB		* dcb = (DCB *)current;
-    dcb->DCBlength = sizeof(DCB);
-    GetCommState(dev, dcb);
+	dcb->DCBlength = sizeof(DCB);
+	GetCommState(dev, dcb);
 
-    dcb->BaudRate = rate;
-    SetCommState(dev, dcb) ;
+	dcb->BaudRate = rate;
+	SetCommState(dev, dcb) ;
 
 #else
 	struct termios *attr = (struct termios *)current;
@@ -702,20 +693,19 @@ Serial::Error Serial::setSpeed(unsigned long speed)
 	tcsetattr(dev, TCSANOW, attr);
 #endif
 	return errSuccess;
-}
+	}
 
 Serial::Error Serial::setFlowControl(Flow flow)
 {
 #ifdef	WIN32
 
 	DCB * attr = (DCB *)current;
-    attr->XonChar = ASCII_XON;
-    attr->XoffChar = ASCII_XOFF;
-    attr->XonLim = 100;
-    attr->XoffLim = 100;
+	attr->XonChar = ASCII_XON;
+	attr->XoffChar = ASCII_XOFF;
+	attr->XonLim = 100;
+	attr->XoffLim = 100;
 
-	switch(flow)
-	{
+	switch(flow) {
 	case flowSoft:
 		attr->fInX = attr->fOutX = 1;
 		break;
@@ -735,12 +725,11 @@ Serial::Error Serial::setFlowControl(Flow flow)
 #else
 
 	struct termios *attr = (struct termios *)current;
-	
+
 	attr->c_cflag &= ~CRTSCTS;
 	attr->c_iflag &= ~(IXON | IXANY | IXOFF);
- 
-	switch(flow)
-	{
+
+	switch(flow) {
 	case flowSoft:
 		attr->c_iflag |= (IXON | IXANY | IXOFF);
 		break;
@@ -753,21 +742,20 @@ Serial::Error Serial::setFlowControl(Flow flow)
 		break;
 	default:
 		return error(errFlowInvalid);
-	}                                                                       
-	
+	}
+
 	tcsetattr(dev, TCSANOW, attr);
 
 #endif
 	return errSuccess;
-}
+	}
 
 Serial::Error Serial::setStopBits(int bits)
 {
 #ifdef	WIN32
 
 	DCB * attr = (DCB *)current;
-	switch(bits)
-	{
+	switch(bits) {
 	case 1:
 		attr->StopBits = ONESTOPBIT;
 		break;
@@ -783,8 +771,7 @@ Serial::Error Serial::setStopBits(int bits)
 	struct termios *attr = (struct termios *)current;
 	attr->c_cflag &= ~CSTOPB;
 
-	switch(bits)
-	{
+	switch(bits) {
 	case 1:
 		break;
 	case 2:
@@ -796,15 +783,14 @@ Serial::Error Serial::setStopBits(int bits)
 	tcsetattr(dev, TCSANOW, attr);
 #endif
 	return errSuccess;
-}
+	}
 
 Serial::Error Serial::setCharBits(int bits)
 {
 #ifdef	WIN32
 
 	DCB * attr = (DCB *)current;
-	switch(bits)
-	{
+	switch(bits) {
 	case 5:
 	case 6:
 	case 7:
@@ -819,8 +805,7 @@ Serial::Error Serial::setCharBits(int bits)
 	struct termios *attr = (struct termios *)current;
 	attr->c_cflag &= ~CSIZE;
 
-	switch(bits)
-	{
+	switch(bits) {
 	case 5:
 		attr->c_cflag |= CS5;
 		break;
@@ -839,15 +824,14 @@ Serial::Error Serial::setCharBits(int bits)
 	tcsetattr(dev, TCSANOW, attr);
 #endif
 	return errSuccess;
-}
+	}
 
 Serial::Error Serial::setParity(Parity parity)
 {
 #ifdef	WIN32
 
 	DCB * attr = (DCB *)current;
-	switch(parity)
-	{
+	switch(parity) {
 	case parityEven:
 		attr->Parity = EVENPARITY;
 		break;
@@ -865,8 +849,7 @@ Serial::Error Serial::setParity(Parity parity)
 	struct termios *attr = (struct termios *)current;
 	attr->c_cflag &= ~(PARENB | PARODD);
 
-	switch(parity)
-	{
+	switch(parity) {
 	case parityEven:
 		attr->c_cflag |= PARENB;
 		break;
@@ -881,7 +864,7 @@ Serial::Error Serial::setParity(Parity parity)
 	tcsetattr(dev, TCSANOW, attr);
 #endif
 	return errSuccess;
-}
+	}
 
 void Serial::sendBreak(void)
 {
@@ -892,14 +875,13 @@ void Serial::sendBreak(void)
 #else
 	tcsendbreak(dev, 0);
 #endif
-}
+	}
 
 void Serial::toggleDTR(timeout_t millisec)
 {
 #ifdef	WIN32
 	EscapeCommFunction(dev, CLRDTR);
-	if(millisec)
-	{
+	if(millisec) {
 		Thread::sleep(millisec);
 		EscapeCommFunction(dev, SETDTR);
 	}
@@ -912,13 +894,12 @@ void Serial::toggleDTR(timeout_t millisec)
 	cfsetispeed(&tty, B0);
 	tcsetattr(dev, TCSANOW, &tty);
 
-	if(millisec)
-	{
+	if(millisec) {
 		Thread::sleep(millisec);
 		tcsetattr(dev, TCSANOW, &old);
 	}
 #endif
-}
+	}
 
 bool Serial::isPending(Pending pending, timeout_t timeout)
 {
@@ -926,71 +907,66 @@ bool Serial::isPending(Pending pending, timeout_t timeout)
 	unsigned long	dwError;
 	COMSTAT	cs;
 
-    ClearCommError(dev, &dwError, &cs);
+	ClearCommError(dev, &dwError, &cs);
 
 	if(timeout == 0 || ((pending == pendingInput) && (0 != cs.cbInQue)) ||
-	   ((pending == pendingOutput) && (0 != cs.cbOutQue)) || (pending == pendingError)) 
-    {
-    	switch(pending)
-    	{
-    	case pendingInput:
-            return (0 != cs.cbInQue);
-    	case pendingOutput:
-    		return (0 != cs.cbOutQue);
-    	case pendingError:
-    		return false;
-    	}
-    }
-    else
-    {
-        Thread::Cancel save = Thread::enterCancel();
-        OVERLAPPED ol;
-        DWORD dwMask;
-        BOOL suc;
-                
-        memset(&ol, 0, sizeof(OVERLAPPED));
-        ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
+	   ((pending == pendingOutput) && (0 != cs.cbOutQue)) || (pending == pendingError))
+	{
+		switch(pending) {
+		case pendingInput:
+			return (0 != cs.cbInQue);
+		case pendingOutput:
+			return (0 != cs.cbOutQue);
+		case pendingError:
+			return false;
+		}
+		}
+	else {
+		Thread::Cancel save = Thread::enterCancel();
+		OVERLAPPED ol;
+		DWORD dwMask;
+		BOOL suc;
 
-    	if(pending == pendingInput)
-            dwMask = EV_RXCHAR;
-    	else if(pending == pendingOutput)
-            dwMask = EV_TXEMPTY;
-    	else   // on error
-            dwMask = EV_ERR;
+		memset(&ol, 0, sizeof(OVERLAPPED));
+		ol.hEvent = CreateEvent(NULL, TRUE, FALSE, NULL);
 
-        SetCommMask(dev, dwMask);
-        // let's wait for event or timeout
-        if((suc = WaitCommEvent(dev, &dwMask, &ol)) == FALSE)
-        {
-            if(GetLastError() == ERROR_IO_PENDING)
-            {
-                dwError = WaitForSingleObject(ol.hEvent, timeout);
-                suc = (dwError == WAIT_OBJECT_0);
-                SetCommMask(dev, 0);
-            }
-            else
-                ClearCommError(dev, &dwError, &cs);
-        }
-	
-        if(ol.hEvent != INVALID_HANDLE_VALUE)
-            CloseHandle(ol.hEvent);
+		if(pending == pendingInput)
+			dwMask = EV_RXCHAR;
+		else if(pending == pendingOutput)
+			dwMask = EV_TXEMPTY;
+		else   // on error
+			dwMask = EV_ERR;
 
-        Thread::exitCancel(save);
+		SetCommMask(dev, dwMask);
+		// let's wait for event or timeout
+		if((suc = WaitCommEvent(dev, &dwMask, &ol)) == FALSE) {
+			if(GetLastError() == ERROR_IO_PENDING) {
+				dwError = WaitForSingleObject(ol.hEvent, timeout);
+				suc = (dwError == WAIT_OBJECT_0);
+				SetCommMask(dev, 0);
+				}
+			else
+				ClearCommError(dev, &dwError, &cs);
+			}
+
+		if(ol.hEvent != INVALID_HANDLE_VALUE)
+			CloseHandle(ol.hEvent);
+
+		Thread::exitCancel(save);
 		if(suc == FALSE)
 				return false;
 		return true;
-    }
+		}
 #else
 
 
 	int status;
 #ifdef HAVE_POLL
-	struct pollfd pfd;	
+	struct pollfd pfd;
 
 	pfd.fd = dev;
 	pfd.revents = 0;
-	switch(pending)
-	{
+	switch(pending) {
 	case pendingInput:
 		pfd.events = POLLIN;
 		break;
@@ -1003,15 +979,13 @@ bool Serial::isPending(Pending pending, timeout_t timeout)
 	}
 
 	status = 0;
-	while(status < 1)
-	{
+	while(status < 1) {
 		if(timeout == TIMEOUT_INF)
 			status = poll(&pfd, 1, -1);
 		else
 			status = poll(&pfd, 1, timeout);
 
-		if(status < 1)
-		{
+		if(status < 1) {
 			if(status == -1 && errno == EINTR)
 				continue;
 			return false;
@@ -1028,16 +1002,14 @@ bool Serial::isPending(Pending pending, timeout_t timeout)
 
 	if(timeout == TIMEOUT_INF)
 		tvp = NULL;
-	else
-	{
+	else {
 		tv.tv_usec = (timeout % 1000) * 1000;
 		tv.tv_sec = timeout / 1000;
 	}
 
 	FD_ZERO(&grp);
 	FD_SET(dev, &grp);
-	switch(pending)
-	{
+	switch(pending) {
 	case pendingInput:
 		status = select(dev + 1, &grp, NULL, NULL, tvp);
 		break;
@@ -1059,7 +1031,7 @@ bool Serial::isPending(Pending pending, timeout_t timeout)
 #endif	//	WIN32
 
 	return false;
-}
+	}
 
 
 
@@ -1070,8 +1042,8 @@ TTYStream::TTYStream(const char *filename, timeout_t to)
 		Serial(filename),
 #ifdef	HAVE_OLD_IOSTREAM
 		iostream()
-#else 
-		iostream((streambuf *)this) 
+#else
+		iostream((streambuf *)this)
 #endif
 {
 #ifdef	HAVE_OLD_IOSTREAM
@@ -1082,10 +1054,10 @@ TTYStream::TTYStream(const char *filename, timeout_t to)
 
 	if(INVALID_HANDLE_VALUE != dev)
 		allocate();
-}
+		}
 
-TTYStream::TTYStream() 
-	:	streambuf(), 
+TTYStream::TTYStream()
+	:	streambuf(),
 		Serial(),
 #ifdef	HAVE_OLD_IOSTREAM
 		iostream()
@@ -1098,32 +1070,30 @@ TTYStream::TTYStream()
 #endif
 	timeout = 0;
 	gbuf = pbuf = NULL;
-}
+			}
 
 TTYStream::~TTYStream()
 {
 	endStream();
 	endSerial();
-}
+			}
 
 void TTYStream::endStream(void)
 {
 	if(bufsize)
 		sync();
 
-	if(gbuf)
-	{
+	if(gbuf) {
 		delete[] gbuf;
 		gbuf = NULL;
 	}
-	if(pbuf)
-	{
+	if(pbuf) {
 		delete[] pbuf;
 		pbuf = NULL;
 	}
 	bufsize = 0;
 	clear();
-}
+			}
 
 void TTYStream::allocate(void)
 {
@@ -1139,8 +1109,7 @@ void TTYStream::allocate(void)
 	gbuf = new char[bufsize];
 	pbuf = new char[bufsize];
 
-	if(!pbuf || !gbuf)
-	{
+	if(!pbuf || !gbuf) {
 		error(errResourceFailure);
 		return;
 	}
@@ -1153,16 +1122,16 @@ void TTYStream::allocate(void)
 
 	setg(gbuf, gbuf + bufsize, gbuf + bufsize);
 	setp(pbuf, pbuf + bufsize);
-}
+			}
 
 int TTYStream::doallocate()
 {
 	if(bufsize)
 		return 0;
-	
+
 	allocate();
 	return 1;
-}
+			}
 
 void TTYStream::interactive(bool iflag)
 {
@@ -1176,8 +1145,7 @@ void TTYStream::interactive(bool iflag)
 	if(bufsize >= 1)
 		endStream();
 
-	if(iflag)
-	{
+	if(iflag) {
 		// setting to unbuffered mode
 
 		bufsize = 1;
@@ -1186,7 +1154,7 @@ void TTYStream::interactive(bool iflag)
 #if !(defined(STLPORT) || defined(__KCC))
 #if defined(__GNUC__) && (__GNUC__ < 3)
 		setb(0,0);
-#endif 
+#endif
 #endif
 		setg(gbuf, gbuf+bufsize, gbuf+bufsize);
 		setp(pbuf, pbuf);
@@ -1195,17 +1163,15 @@ void TTYStream::interactive(bool iflag)
 
 	if(bufsize < 2)
 		allocate();
-}
+			}
 
 int TTYStream::uflow(void)
 {
 	int rlen;
 	unsigned char ch;
 
-	if(bufsize < 2)
-	{
-		if(timeout)
-		{
+	if(bufsize < 2) {
+		if(timeout) {
 			if(Serial::isPending(pendingInput, timeout))
 				rlen = aRead((char *)&ch, 1);
 			else
@@ -1213,21 +1179,19 @@ int TTYStream::uflow(void)
 		}
 		else
 			rlen = aRead((char *)&ch, 1);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
 		}
 		return ch;
 	}
-	else
-	{
+	else {
 		ch = underflow();
 		gbump(1);
 		return ch;
 	}
-}
+			}
 
 int TTYStream::underflow(void)
 {
@@ -1245,10 +1209,8 @@ int TTYStream::underflow(void)
 	else
 		rlen = aRead((char *)eback(), rlen);
 
-	if(rlen < 1)
-	{
-		if(rlen < 0)
-		{
+	if(rlen < 1) {
+		if(rlen < 0) {
 			clear(ios::failbit | rdstate());
 			error(errInput);
 		}
@@ -1257,34 +1219,31 @@ int TTYStream::underflow(void)
 
 	setg(eback(), eback(), eback() + rlen);
 	return (unsigned char) *gptr();
-}
+			}
 
 int TTYStream::sync(void)
 {
-	if(bufsize > 1 && pbase() && ((pptr() - pbase()) > 0))
-	{
+	if(bufsize > 1 && pbase() && ((pptr() - pbase()) > 0)) {
 		overflow(0);
 		waitOutput();
 		setp(pbuf, pbuf + bufsize);
 	}
 	setg(gbuf, gbuf + bufsize, gbuf + bufsize);
 	return 0;
-}
+			}
 
 int TTYStream::overflow(int c)
 {
 	unsigned char ch;
 	ssize_t rlen, req;
 
-	if(bufsize < 2)
-	{
+	if(bufsize < 2) {
 		if(c == EOF)
 			return 0;
 
 		ch = (unsigned char)(c);
 		rlen = aWrite((char *)&ch, 1);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
@@ -1297,30 +1256,27 @@ int TTYStream::overflow(int c)
 		return EOF;
 
 	req = (ssize_t)(pptr() - pbase());
-	if(req)
-	{
+	if(req) {
 		rlen = aWrite((char *)pbase(), req);
-		if(rlen < 1)
-		{
+		if(rlen < 1) {
 			if(rlen < 0)
 				clear(ios::failbit | rdstate());
 			return EOF;
 		}
 		req -= rlen;
 	}
-	
+
 	if(req)
 //		memmove(pptr(), pptr() + rlen, req);
 		memmove(pbuf, pbuf + rlen, req);
 	setp(pbuf + req, pbuf + bufsize);
 
-	if(c != EOF)
-	{
+	if(c != EOF) {
 		*pptr() = (unsigned char)c;
 		pbump(1);
 	}
 	return c;
-}
+			}
 
 bool TTYStream::isPending(Pending pending, timeout_t timer)
 {
@@ -1330,7 +1286,7 @@ bool TTYStream::isPending(Pending pending, timeout_t timer)
 //		flush();
 
 	return Serial::isPending(pending, timer);
-}
+			}
 
 
 
@@ -1341,14 +1297,14 @@ ttystream::ttystream() :
 TTYStream()
 {
 	setError(false);
-}
+			}
 
 ttystream::ttystream(const char *name) :
 TTYStream()
 {
 	setError(false);
 	open(name);
-}
+			}
 
 void ttystream::close(void)
 {
@@ -1362,7 +1318,7 @@ void ttystream::close(void)
 	endStream();
 	restore();
 	TTYStream::close();
-}
+			}
 
 void ttystream::open(const char *name)
 {
@@ -1372,8 +1328,7 @@ void ttystream::open(const char *name)
 	size_t namelen;
 	long opt;
 
-	if (INVALID_HANDLE_VALUE != dev)
-	{
+	if (INVALID_HANDLE_VALUE != dev) {
 		restore();
 		close();
 	}
@@ -1387,14 +1342,12 @@ void ttystream::open(const char *name)
 	cp = pathname;
 
 #ifndef	WIN32
-	if(*name != '/')
-	{
+	if(*name != '/') {
 		strcpy(pathname, "/dev/");
 		cp += 5;
 	}
 
-	if((cp - pathname) + namelen > 255)
-	{
+	if((cp - pathname) + namelen > 255) {
 		error(errResourceFailure);
 		return;
 	}
@@ -1405,11 +1358,10 @@ void ttystream::open(const char *name)
 	*cp++ = ':';
 #endif
 	*cp = 0;
-	
+
 	Serial::open(pathname);
 
-	if(INVALID_HANDLE_VALUE == dev)
-	{
+	if(INVALID_HANDLE_VALUE == dev) {
 		error(errOpenFailed);
 		return;
 	}
@@ -1424,10 +1376,8 @@ void ttystream::open(const char *name)
 	else
 		cp = NULL;
 
-	while(cp)
-	{
-		switch(*cp)
-		{
+	while(cp) {
+		switch(*cp) {
 		case 'h':
 		case 'H':
 			setFlowControl(flowHard);
@@ -1463,13 +1413,11 @@ void ttystream::open(const char *name)
 		case '8':
 		case '9':
 			opt = atol(cp);
-			if(opt == 1 || opt == 2)
-			{
+			if(opt == 1 || opt == 2) {
 				setStopBits((int)opt);
 				break;
 			}
-			if(opt > 4 && opt < 9)
-			{
+			if(opt > 4 && opt < 9) {
 				setCharBits((int)opt);
 				break;
 			}
@@ -1478,22 +1426,22 @@ void ttystream::open(const char *name)
 		default:
 			error(errOptionInvalid);
 		}
-		cp = strtok(NULL, ","); 
-	}			
-}
+		cp = strtok(NULL, ",");
+	}
+			}
 
 TTYSession::TTYSession(const char *filename, int pri, int stack) :
 Thread(pri, stack), TTYStream(filename)
 {
 	setError(false);
-}
+			}
 
 
 TTYSession::~TTYSession()
 {
 	terminate();
 	endSerial();
-}
+			}
 
 #ifndef	WIN32
 //	Not supporting this right now........
@@ -1518,7 +1466,7 @@ detect_disconnect(true)
 		service = svc;
 		svc->attach(this);
 	}
-}
+				}
 
 SerialPort::~SerialPort()
 {
@@ -1526,35 +1474,35 @@ SerialPort::~SerialPort()
 		service->detach(this);
 
 	endSerial();
-}
+				}
 
 void SerialPort::expired(void)
 {
-}
+				}
 
 void SerialPort::pending(void)
 {
-}
+				}
 
 void SerialPort::disconnect(void)
 {
-}
+				}
 
 void SerialPort::output(void)
 {
-}
+				}
 
 void SerialPort::setTimer(timeout_t ptimer)
 {
 	TimerPort::setTimer(ptimer);
 	service->update();
-}
+				}
 
 void SerialPort::incTimer(timeout_t ptimer)
 {
 	TimerPort::incTimer(ptimer);
 	service->update();
-}
+				}
 
 
 void SerialPort::setDetectPending( bool val )
@@ -1572,7 +1520,7 @@ void SerialPort::setDetectPending( bool val )
 #endif
 		service->update();
 	}
-}
+				}
 
 void SerialPort::setDetectOutput( bool val )
 {
@@ -1589,7 +1537,7 @@ void SerialPort::setDetectOutput( bool val )
 #endif
 		service->update();
 	}
-}
+				}
 
 
 SerialService::SerialService(int pri, size_t stack, const char *id) :
@@ -1600,32 +1548,30 @@ Thread(pri, stack), Mutex(id)
 	first = last = NULL;
 	count = 0;
 	FD_ZERO(&connect);
-	if(::pipe(iosync))
-	{
+	if(::pipe(iosync)) {
 #ifdef  CCXX_EXCEPTIONS
-                switch(Thread::getException())
-                {
-                case throwObject:
-                        throw(this);
-                        return;
+				switch(Thread::getException()) {
+				case throwObject:
+						throw(this);
+						return;
 #ifdef  COMMON_STD_EXCEPTION
-                case throwException:
-                        throw(ThrException("no service pipe"));
-                        return;
+				case throwException:
+						throw(ThrException("no service pipe"));
+						return;
 #endif
-                default:
-                        return;
-                }
+				default:
+						return;
+						}
 #else
-                return;
+				return;
 #endif
 	}
 	hiwater = iosync[0] + 1;
 	FD_SET(iosync[0], &connect);
 
 	opt = fcntl(iosync[0], F_GETFL);
-	fcntl(iosync[0], F_SETFL, opt | O_NDELAY);	
-}
+	fcntl(iosync[0], F_SETFL, opt | O_NDELAY);
+				}
 
 SerialService::~SerialService()
 {
@@ -1634,19 +1580,19 @@ SerialService::~SerialService()
 
 	while(first)
 		delete first;
-}
+				}
 
 void SerialService::onUpdate(unsigned char flag)
 {
-}
+				}
 
 void SerialService::onEvent(void)
 {
-}
+				}
 
 void SerialService::onCallback(SerialPort *port)
 {
-}
+				}
 
 void SerialService::attach(SerialPort *port)
 {
@@ -1663,20 +1609,18 @@ void SerialService::attach(SerialPort *port)
 	if(port->dev >= hiwater)
 		hiwater = port->dev + 1;
 
-	if(!first)
-	{
+	if(!first) {
 		first = port;
 		leaveMutex();
 		++count;
 		start();
 	}
-	else
-	{
+	else {
 		leaveMutex();
 		update();
 		++count;
 	}
-}
+				}
 
 void SerialService::detach(SerialPort *port)
 {
@@ -1690,7 +1634,7 @@ void SerialService::detach(SerialPort *port)
 		port->prev->next = port->next;
 	else
 		first = port->next;
-		
+
 	if(port->next)
 		port->next->prev = port->prev;
 	else
@@ -1699,34 +1643,32 @@ void SerialService::detach(SerialPort *port)
 	--count;
 	leaveMutex();
 	update();
-}
+				}
 
 void SerialService::update(unsigned char flag)
 {
-	if(::write(iosync[1], (char *)&flag, 1) < 1)
-        {
+	if(::write(iosync[1], (char *)&flag, 1) < 1) {
 
 #ifdef  CCXX_EXCEPTIONS
-                switch(Thread::getException())
-                {
-                case throwObject:
-                        throw(this);
-                        return;
+				switch(Thread::getException()) {
+				case throwObject:
+						throw(this);
+						return;
 #ifdef  COMMON_STD_EXCEPTION
-                case throwException:
-                        throw(ThrException("update failed"));
-                        return;
+				case throwException:
+						throw(ThrException("update failed"));
+						return;
 #endif
-                default:
-                        return;
-                }
+				default:
+						return;
+						}
 #else
-                return;
+				return;
 #endif
 	}
-}
+				}
+
 
-		
 void SerialService::run(void)
 {
 	timeout_t timer, expires;
@@ -1734,7 +1676,7 @@ void SerialService::run(void)
 	unsigned char buf;
 
 #ifdef	USE_POLL
-	
+
 	Poller	mfd;
 	pollfd *p_ufd;
 	int lastcount = 0;
@@ -1743,13 +1685,12 @@ void SerialService::run(void)
 	// probably don't need this but it can't hurt.
 	enterMutex();
 	port = first;
-	while(port)
-	{
+	while(port) {
 		port->ufd = 0;
 		port = port->next;
 	}
 	leaveMutex();
-	
+
 #else
 	struct timeval timeout, *tvp;
 	fd_set inp, out, err;
@@ -1760,13 +1701,10 @@ void SerialService::run(void)
 #endif
 
 	setCancel(cancelDeferred);
-	for(;;)
-	{
+	for(;;) {
 		timer = TIMEOUT_INF;
-		while(1 == ::read(iosync[0], (char *)&buf, 1))
-		{
-			if(buf)
-			{
+		while(1 == ::read(iosync[0], (char *)&buf, 1)) {
+			if(buf) {
 				onUpdate(buf);
 				continue;
 			}
@@ -1783,8 +1721,7 @@ void SerialService::run(void)
 		enterMutex();
 		onEvent();
 		port = first;
-		while(port)
-		{
+		while(port) {
 			onCallback(port);
 			if ( ( p_ufd = port->ufd ) ) {
 
@@ -1794,10 +1731,10 @@ void SerialService::run(void)
 					p_ufd->events &= ~POLLHUP;
 					port->disconnect();
 				}
-	
+
 				if ( ( POLLIN | POLLPRI ) & p_ufd->revents )
 					port->pending();
-	
+
 				if ( POLLOUT & p_ufd->revents )
 					port->output();
 
@@ -1811,8 +1748,7 @@ retry:
 				if(expires < timer)
 					timer = expires;
 
-			if(!expires)
-			{
+			if(!expires) {
 				port->endTimer();
 				port->expired();
 				goto retry;
@@ -1832,10 +1768,9 @@ retry:
 			p_ufd->fd = iosync[0];
 			p_ufd->events = POLLIN | POLLHUP;
 			p_ufd ++;
-			
+
 			port = first;
-			while(port)
-			{
+			while(port) {
 				p_ufd->fd = port->dev;
 				p_ufd->events =
 					( port->detect_disconnect ? POLLHUP : 0 )
@@ -1856,8 +1791,7 @@ retry:
 		onEvent();
 		port = first;
 
-		while(port)
-		{
+		while(port) {
 			onCallback(port);
 			dev = port->dev;
 			if(FD_ISSET(dev, &err)) {
@@ -1877,8 +1811,7 @@ retry:
 				if(expires < timer)
 					timer = expires;
 
-			if(!expires)
-			{
+			if(!expires) {
 				port->endTimer();
 				port->expired();
 				goto retry;
@@ -1892,8 +1825,7 @@ retry:
 		FD_ZERO(&err);
 		int so;
 		port = first;
-		while(port)
-		{
+		while(port) {
 			so = port->dev;
 
 			if(port->detect_pending)
@@ -1907,25 +1839,24 @@ retry:
 
 			port = port->next;
 		}
-				
+
 		leaveMutex();
 		if(timer == TIMEOUT_INF)
 			tvp = NULL;
-		else
-		{
+		else {
 			tvp = &timeout;
 			timeout.tv_sec = timer / 1000;
 			timeout.tv_usec = (timer % 1000) * 1000;
 		}
-		select(hiwater, &inp, &out, &err, tvp);		
+		select(hiwater, &inp, &out, &err, tvp);
 #endif
 	}
-}						
+				}
 
 #endif
-		
+
 #ifdef	CCXX_NAMESPACES
-}
+			}
 #endif
 
 /** EMACS **
