@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -78,11 +78,11 @@ streambuf()
 #endif
 	_enable = true;
 	_level = levelDebug;
-        _clogEnable = true;
+		_clogEnable = true;
 #ifndef	HAVE_SYSLOG_H
 	syslog = NULL;
 #endif
-}
+	}
 
 Slog::~Slog(void)
 {
@@ -92,7 +92,7 @@ Slog::~Slog(void)
 	if(syslog)
 			fclose(syslog);
 #endif
-}
+	}
 
 ThreadImpl *Slog::getPriv(void)
 {
@@ -102,7 +102,7 @@ ThreadImpl *Slog::getPriv(void)
 		return NULL;
 
 	return thread->priv;
-}
+	}
 
 void Slog::close(void)
 {
@@ -115,7 +115,7 @@ void Slog::close(void)
 	syslog = NULL;
 	lock.leaveMutex();
 #endif
-}
+	}
 
 void Slog::open(const char *ident, Class grp)
 {
@@ -128,8 +128,7 @@ void Slog::open(const char *ident, Class grp)
 
 	int fac;
 
-	switch(grp)
-	{
+	switch(grp) {
 	case classUser:
 		fac = LOG_USER;
 		break;
@@ -194,16 +193,15 @@ void Slog::open(const char *ident, Class grp)
 	strcpy(buf, ident);
 	cp = (const char *)buf;
 	buf = strrchr(buf, '.');
-	if(buf)
-	{
-                if(!stricmp(buf, ".exe"))
-                        strcpy(buf, ".log");
+	if(buf) {
+				if(!stricmp(buf, ".exe"))
+			strcpy(buf, ".log");
 	}
 	syslog = fopen(cp, "a");
 	delete[] (char *)cp;
 	lock.leaveMutex();
 #endif
-}
+	}
 
 #ifdef	HAVE_SNPRINTF
 
@@ -223,7 +221,7 @@ void Slog::error(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::warn(const char *format, ...)
 {
@@ -240,7 +238,7 @@ void Slog::warn(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::debug(const char *format, ...)
 {
@@ -257,7 +255,7 @@ void Slog::debug(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::emerg(const char *format, ...)
 {
@@ -274,7 +272,7 @@ void Slog::emerg(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::alert(const char *format, ...)
 {
@@ -291,7 +289,7 @@ void Slog::alert(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::critical(const char *format, ...)
 {
@@ -308,7 +306,7 @@ void Slog::critical(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::notice(const char *format, ...)
 {
@@ -325,13 +323,13 @@ void Slog::notice(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 
 void Slog::info(const char *format, ...)
 {
 	ThreadImpl *thread = getPriv();
 	va_list args;
-	
+
 	if(!thread)
 		return;
 
@@ -342,7 +340,7 @@ void Slog::info(const char *format, ...)
 	thread->_msgpos = strlen(thread->_msgbuf);
 	overflow(EOF);
 	va_end(args);
-}
+	}
 #endif
 
 int Slog::overflow(int c)
@@ -351,8 +349,7 @@ int Slog::overflow(int c)
 	if(!thread)
 		return c;
 
-	if(c == '\n' || !c || c == EOF)
-	{
+	if(c == '\n' || !c || c == EOF) {
 		if(!thread->_msgpos)
 			return c;
 
@@ -368,8 +365,7 @@ int Slog::overflow(int c)
 			dt = localtime(&now);
 			char buf[256];
 			const char *p = "unknown";
-			switch(priority)
-			{
+			switch(priority) {
 			case levelEmergency:
 				p = "emerg";
 				break;
@@ -397,7 +393,7 @@ int Slog::overflow(int c)
 			}
 
 			lock.enterMutex();
-			snprintf(buf, sizeof(buf), "%04d-%02d-%02d %02d:%02d:%02d [%s] %s\n", 
+			snprintf(buf, sizeof(buf), "%04d-%02d-%02d %02d:%02d:%02d [%s] %s\n",
 				dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday,
 				dt->tm_hour, dt->tm_min, dt->tm_sec,
 				p, thread->_msgbuf);
@@ -411,9 +407,9 @@ int Slog::overflow(int c)
 
 		if ( _enable && _clogEnable
 #ifndef	WIN32
-                     && (getppid() > 1)
+					 && (getppid() > 1)
 #endif
-                     )
+					 )
 			clog << thread->_msgbuf << endl;
 		_enable = true;
 		return c;
@@ -423,7 +419,7 @@ int Slog::overflow(int c)
 		thread->_msgbuf[thread->_msgpos++] = c;
 
 	return c;
-}
+		}
 
 Slog &Slog::operator()(const char *ident, Class grp, Level lev)
 {
@@ -436,7 +432,7 @@ Slog &Slog::operator()(const char *ident, Class grp, Level lev)
 	_enable = true;
 	open(ident, grp);
 	return this->operator()(lev, grp);
-}
+		}
 
 Slog &Slog::operator()(Level lev, Class grp)
 {
@@ -452,8 +448,7 @@ Slog &Slog::operator()(Level lev, Class grp)
 		_enable = false;
 
 #ifdef	HAVE_SYSLOG_H
-	switch(lev)
-	{
+	switch(lev) {
 	case levelEmergency:
 		priority = LOG_EMERG;
 		break;
@@ -479,8 +474,7 @@ Slog &Slog::operator()(Level lev, Class grp)
 		priority = LOG_DEBUG;
 		break;
 	}
-	switch(grp)
-	{
+	switch(grp) {
 	case classAudit:
 #ifdef	LOG_AUTHPRIV
 		priority |= LOG_AUTHPRIV;
@@ -527,15 +521,15 @@ Slog &Slog::operator()(Level lev, Class grp)
 	priority = lev;
 #endif
 	return *this;
-}
+		}
 
 Slog &Slog::operator()(void)
 {
 	return *this;
-}	
+		}
 
 #ifdef	CCXX_NAMESPACES
-}
+	}
 #endif
 
 /** EMACS **
