@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -78,8 +78,8 @@ String::String()
 
 String::String(std::string str)
 {
-       init();
-       set(str.c_str());
+	   init();
+	   set(str.c_str());
 }
 
 String::String(const String &original)
@@ -99,27 +99,27 @@ String::String(size_t chars, const char chr)
 #ifdef	HAVE_SNPRINTF
 String::String(size_t chars, const char *format, ...)
 {
-        va_list args;
-        va_start(args, format);
+	va_list args;
+	va_start(args, format);
 
 	init();
 	resize(chars);
 
-        char *ptr = getText();
+	char *ptr = getText();
 	vsnprintf(ptr, chars, format, args);
-        setLength(strlen(ptr));
+	setLength(strlen(ptr));
 	va_end(args);
 }
 #else
 String::String(size_t chars, const char *str)
 {
-        init();
-        resize(chars);
+	init();
+	resize(chars);
 
-        if(!str || !*str)
-                return;
+	if(!str || !*str)
+		return;
 
-        set(str);
+	set(str);
 }
 #endif
 
@@ -140,7 +140,7 @@ String::String(const String &str, size_t start, size_t chars)
 
 	ptr += start;
 	len -= start;
-	
+
 	if(chars >= len)
 		chars = len;
 
@@ -172,14 +172,12 @@ void String::insert(size_t start, const char *str, size_t chars)
 	if(!chars || start > len)
 		return;
 
-	if(len + chars >= sz)
-	{
+	if(len + chars >= sz) {
 		resize(len + chars + 1);
 		ptr = getText();
 	}
 
-	if(start == len)
-	{
+	if(start == len) {
 		memmove(ptr + start, str, chars);
 		len += chars;
 		setLength(len);
@@ -193,7 +191,7 @@ void String::insert(size_t start, const char *str, size_t chars)
 	setLength(len);
 	ptr[len] = 0;
 	return;
-}	
+}
 
 
 void String::insert(size_t start, const String &s)
@@ -217,16 +215,15 @@ void String::erase(size_t start, size_t chars)
 {
 	size_t len = getLength();
 	char *ptr = getText();
-		
+
 	if(start >= len)
 		return;
 
-	if(start + chars >= len || chars == npos || !chars)
-	{
+	if(start + chars >= len || chars == npos || !chars) {
 		setLength(start);
 		ptr[start] = 0;
 		return;
-	}		
+	}
 
 	memmove(ptr + start, ptr + start + chars, len - start - chars);
 	len -= chars;
@@ -239,8 +236,7 @@ void String::append(const char *str, size_t offset, size_t len)
 	size_t slen = getLength();
 	char *ptr = getText();
 
-	if(slen < offset)
-	{
+	if(slen < offset) {
 		append(str, len);
 		return;
 	}
@@ -277,7 +273,7 @@ void String::add(char c)
 
 	if(len + 1 >= getSize())
 		resize(len + 2);
-	
+
 	ptr = getText();
 	ptr[len++] = c;
 	setLength(len);
@@ -299,10 +295,10 @@ void String::trim(size_t chars)
 
 String String::token(const char *delim, size_t offset)
 {
-        char *ptr = getText();
-        size_t len = getLength();
-        size_t chars = 0;
-        String result;
+	char *ptr = getText();
+	size_t len = getLength();
+	size_t chars = 0;
+	String result;
 	bool found = false;
 
 	if(offset >= len)
@@ -310,35 +306,32 @@ String String::token(const char *delim, size_t offset)
 
 	len -= offset;
 	ptr += offset;
-                                                                        
-        while(chars < len)
-        {
-                if(strchr(delim, ptr[chars]))
-		{
+
+	while(chars < len) {
+		if(strchr(delim, ptr[chars])) {
 			found = true;
-                        break;
+			break;
 		}
-                ++chars;
-        }
+		++chars;
+	}
 
 	if(!chars && found)
 		erase(offset, 1);
-                                                                        
-        if(!chars)
+
+	if(!chars)
 		return result;
 
-        result.set(ptr, chars);                                                                        
+	result.set(ptr, chars);
 	if(found)
 		++chars;
-        erase(offset, chars);
+	erase(offset, chars);
 	return result;
 }
 
 void String::strip(const char *chars)
 {
 	size_t len = strtrim(chars, getText(), getLength());
-	if(!len)
-	{
+	if(!len) {
 		setLength(len);
 		return;
 	}
@@ -348,8 +341,8 @@ void String::strip(const char *chars)
 #ifdef	HAVE_SNPRINTF
 const char *String::set(size_t chars, const char *format, ...)
 {
-        va_list args;
-        va_start(args, format);
+	va_list args;
+	va_start(args, format);
 
 	if(chars <= minsize)
 		clear();
@@ -357,17 +350,17 @@ const char *String::set(size_t chars, const char *format, ...)
 	if(chars > getSize())
 		resize(chars);
 
-        char *ptr = getText();
+	char *ptr = getText();
 	vsnprintf(ptr, chars, format, args);
-        setLength(strlen(ptr));
+	setLength(strlen(ptr));
 	va_end(args);
 	return ptr;
 }
 
 void String::append(size_t chars, const char *format, ...)
 {
-        va_list args;
-        va_start(args, format);
+	va_list args;
+	va_start(args, format);
 	size_t len = getLength();
 
 	if(len + chars <= minsize)
@@ -376,17 +369,16 @@ void String::append(size_t chars, const char *format, ...)
 	if(len + chars > getSize())
 		resize(len + chars);
 
-        char *ptr = getText() + len;
+	char *ptr = getText() + len;
 	vsnprintf(ptr, chars, format, args);
-        setLength(strlen(getText()));
+	setLength(strlen(getText()));
 	va_end(args);
 }
 
 #endif
 const char *String::set(const char *str, size_t len)
 {
-	if(!str)
-	{
+	if(!str) {
 		clear();
 		return str;
 	}
@@ -422,8 +414,7 @@ void String::copy(const String &original)
 {
 	clear();
 
-	if(original.getLength() < minsize)
-	{
+	if(original.getLength() < minsize) {
 		content.ministring.length = (unsigned)original.getLength();
 		memmove(content.ministring.text, original.getText(), original.getLength() + 1);
 		content.ministring.big = false;
@@ -453,15 +444,14 @@ void String::init(void)
 size_t String::search(const char *cp, size_t clen, size_t ind) const
 {
 	size_t len = getLength();
-	 
+
 	if(!cp)
 		cp = "";
 
 	if(!clen)
 		clen = strlen(cp);
 
-	while(clen + ind <= len)
-	{
+	while(clen + ind <= len) {
 		if(compare(cp, clen, ind) == 0)
 			return ind;
 		++ind;
@@ -471,7 +461,7 @@ size_t String::search(const char *cp, size_t clen, size_t ind) const
 
 size_t String::find(const char *cp, size_t ind, size_t len, unsigned instance) const
 {
-	size_t pos;
+	size_t pos = npos;
 
 	if(!cp)
 		cp = "";
@@ -479,8 +469,7 @@ size_t String::find(const char *cp, size_t ind, size_t len, unsigned instance) c
 	if(!len)
 		len = strlen(cp);
 
-	while(instance--)
-	{
+	while(instance--) {
 		pos = search(cp, len, ind);
 		if(pos == npos)
 			break;
@@ -493,14 +482,13 @@ size_t String::rfind(const char *cp, size_t ind, size_t len) const
 {
 	size_t result = npos;
 
-        if(!cp)
-                cp = "";
+	if(!cp)
+		cp = "";
 
-        if(!len)
-                len = strlen(cp);
+	if(!len)
+		len = strlen(cp);
 
-	for(;;)
-	{
+	for(;;) {
 		ind = search(cp, len, ind);
 		if(ind == npos)
 			break;
@@ -518,8 +506,7 @@ unsigned String::count(const char *cp, size_t ind, size_t len) const
 	if(!len)
 		len = strlen(cp);
 
-	for(;;)
-	{
+	for(;;) {
 		ind = search(cp, len, ind);
 		if(ind == npos)
 			break;
@@ -581,10 +568,9 @@ void String::resize(size_t chars)
 	if(!isBig() && chars <= minsize)
 		return;
 
-	if(!isBig())
-	{
+	if(!isBig()) {
 		ptr = getSpace(chars);
-		memmove(ptr, content.ministring.text, len); 
+		memmove(ptr, content.ministring.text, len);
 		ptr[--len] = 0;
 		content.ministring.big = true;
 		content.bigstring.text = ptr;
@@ -592,9 +578,8 @@ void String::resize(size_t chars)
 		setSize(chars);
 		return;
 	}
-	
-	if(chars <= minsize && getSize() > slotlimit)
-	{
+
+	if(chars <= minsize && getSize() > slotlimit) {
 		ptr = getText();
 		memmove(content.ministring.text, ptr, len);
 		content.ministring.text[--len] = 0;
@@ -623,10 +608,9 @@ void String::clear(void)
 		goto end;
 
 	if(!content.bigstring.text)
-		goto end; 
+		goto end;
 
-	if(getSize() > slotlimit)
-	{
+	if(getSize() > slotlimit) {
 		delete[] content.bigstring.text;
 		goto end;
 	}
@@ -638,12 +622,12 @@ void String::clear(void)
 	idx[slot] = content.bigstring.text;
 	setLength(0);
 	content.bigstring.text = NULL;
-	mutex.leaveMutex();	
-	
+	mutex.leaveMutex();
+
 end:
 	init();
 	return;
-}	
+}
 
 char *String::getSpace(size_t chars)
 {
@@ -655,15 +639,13 @@ char *String::getSpace(size_t chars)
 
 	slot = (unsigned)chars / slotsize;
 	mutex.enterMutex();
-	if(!pager)
-	{
+	if(!pager) {
 		pager = new MemPager(pagesize);
 		idx = (char **)pager->alloc(sizeof(char *) * slotcount);
 		memset(idx, 0, sizeof(char *) * slotcount);
 	}
 	cp = idx[slot];
-	if(cp)
-	{
+	if(cp) {
 		next = (char **)cp;
 		idx[slot] = *next;
 	}
@@ -682,7 +664,7 @@ const char *String::getIndex(size_t ind) const
 
 	return (const char *)dp + ind;
 }
-		
+
 char *String::getText(void) const
 {
 	if(isBig())
@@ -701,8 +683,7 @@ long String::getValue(long def) const
 	if(!cp)
 		return def;
 
-	if(!strnicmp(cp, "0x", 2))
-	{
+	if(!strnicmp(cp, "0x", 2)) {
 		cp += 2;
 		base = 16;
 	}
@@ -720,8 +701,7 @@ bool String::getBool(bool def) const
 	if(!cp)
 		return def;
 
-	if(isdigit(*cp))
-	{
+	if(isdigit(*cp)) {
 		if(!getValue(0))
 			return false;
 		return true;
@@ -734,8 +714,8 @@ bool String::getBool(bool def) const
 		return false;
 
 	return def;
-}		
-	
+}
+
 const size_t String::getSize(void) const
 {
 	if(isBig())
@@ -757,11 +737,10 @@ size_t String::setSize(size_t chars)
 	if(chars <= minsize && !isBig())
 		return minsize;
 
-  if(chars <= slotlimit)
-  {
-    size_t slotcount = chars / slotsize;
-    if((chars % slotsize)!=0) ++slotcount;
-    chars = slotcount*slotsize;
+  if(chars <= slotlimit) {
+	size_t slotcount = chars / slotsize;
+	if((chars % slotsize)!=0) ++slotcount;
+	chars = slotcount*slotsize;
   }
 	content.bigstring.size = chars;
 	return chars;
@@ -812,34 +791,34 @@ String operator+(const char c1, const String &s2)
 
 bool String::operator<(const String &s1) const
 {
-        if(compare(s1.getText()) < 0)
-                return true;
+	if(compare(s1.getText()) < 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator<(const char *s1) const
 {
-        if(compare(s1) < 0)
-                return true;
+	if(compare(s1) < 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator>(const String &s1) const
 {
-        if(compare(s1.getText()) > 0)
-                return true;
+	if(compare(s1.getText()) > 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator>(const char *s1) const
 {
-        if(compare(s1) > 0)
-                return true;
+	if(compare(s1) > 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator<=(const String &s1) const
@@ -852,58 +831,58 @@ bool String::operator<=(const String &s1) const
 
 bool String::operator<=(const char *s1) const
 {
-        if(compare(s1) <= 0)
-                return true;
+	if(compare(s1) <= 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator>=(const String &s1) const
 {
-        if(compare(s1.getText()) >= 0)
-                return true;
+	if(compare(s1.getText()) >= 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator>=(const char *s1) const
 {
-        if(compare(s1) >= 0)
-                return true;
+	if(compare(s1) >= 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator==(const String &s1) const
 {
-        if(compare(s1.getText()) == 0)
-                return true;
+	if(compare(s1.getText()) == 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator==(const char *s1) const
 {
-        if(compare(s1) == 0)
-                return true;
+	if(compare(s1) == 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator!=(const String &s1) const
 {
-        if(compare(s1.getText()) != 0)
-                return true;
+	if(compare(s1.getText()) != 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator!=(const char *s1) const
 {
-        if(compare(s1) != 0)
-                return true;
+	if(compare(s1) != 0)
+		return true;
 
-        return false;
+	return false;
 }
 
 bool String::operator*=(const String &s1) const
@@ -940,14 +919,14 @@ void *StringObject::operator new(size_t size) NEW_THROWS
 	*sp = size;
 	base += sizeof(size_t);
 	return (void *)base;
-}	
+}
 
 void StringObject::operator delete(void *ptr)
 {
 	char **next;
 	unsigned slot;
 	size_t *size = (size_t *)ptr;
-	
+
 	--size;
 	ptr = size;
 
@@ -958,8 +937,8 @@ void StringObject::operator delete(void *ptr)
 	String::idx[slot] = (char *)ptr;
 	mutex.leave();
 }
-	
-	
+
+
 
 std::istream &getline(std::istream &is, String &str, char delim, size_t len)
 {
@@ -984,9 +963,9 @@ String(), streambuf()
 #endif
 {
 #ifdef  HAVE_OLD_IOSTREAM
-        ostream::init((streambuf *)this);
+		ostream::init((streambuf *)this);
 #endif
-}
+	}
 
 SString::SString(const SString &from) :
 String(from), streambuf()
@@ -997,21 +976,21 @@ String(from), streambuf()
 #endif
 {
 #ifdef  HAVE_OLD_IOSTREAM
-        ostream::init((streambuf *)this);
+		ostream::init((streambuf *)this);
 #endif
-}
+		}
 
 SString::~SString()
 {
 	if(isBig())
 		String::clear();
-}
+		}
 
 int SString::overflow(int c)
 {
 	String::add((char)(c));
 	return c;
-}
+		}
 
 #ifdef	HAVE_SNPRINTF
 int strprintf(String &str, size_t size, const char *format, ...)
@@ -1033,11 +1012,11 @@ int strprintf(String &str, size_t size, const char *format, ...)
 	str.setLength(strlen(ptr));
 	va_end(args);
 	return rtn;
-}
+		}
 #endif
 
 #ifdef	CCXX_NAMESPACES
-}
+	}
 #endif
 
 /** EMACS **
