@@ -1,27 +1,27 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
-//  
+//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
+// along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-// 
+//
 // As a special exception, you may use this file as part of a free software
 // library without restriction.  Specifically, if other files instantiate
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -136,17 +136,17 @@ static inline void ccxx_suspend(cctid_t tid) { pthread_suspend(tid); }
 # if defined(_THR_SUNOS5) || defined(CCXX_SIG_THREAD_STOPCONT)
 #  define CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_NOT_RECURSIVE
 #  ifdef _THR_SUNOS5
-    static inline void ccxx_resume(cctid_t tid) { thr_continue((thread_t)tid); }
-    static inline void ccxx_suspend(cctid_t tid) { thr_suspend((thread_t)tid); }
+	static inline void ccxx_resume(cctid_t tid) { thr_continue((thread_t)tid); }
+	static inline void ccxx_suspend(cctid_t tid) { thr_suspend((thread_t)tid); }
 #  else
 #   define CCXX_SIG_THREAD_SUSPEND SIGSTOP
 #   define CCXX_SIG_THREAD_RESUME  SIGCONT
-    static inline void ccxx_resume(cctid_t tid) { 
-	    pthread_kill(tid, CCXX_SIG_THREAD_RESUME); 
-    }
-    static inline void ccxx_suspend(cctid_t tid) { 
-	    pthread_kill(tid, CCXX_SIG_THREAD_SUSPEND); 
-    }
+	static inline void ccxx_resume(cctid_t tid) {
+	    pthread_kill(tid, CCXX_SIG_THREAD_RESUME);
+}
+	static inline void ccxx_suspend(cctid_t tid) {
+	    pthread_kill(tid, CCXX_SIG_THREAD_SUSPEND);
+}
 #  endif
 # else
 #  define CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_ONE_SIGNAL
@@ -159,11 +159,11 @@ static inline void ccxx_suspend(cctid_t tid) { pthread_suspend(tid); }
 #  endif
 #  define CCXX_SIG_THREAD_SUSPEND SIGUSR3
 #  define CCXX_SIG_THREAD_RESUME SIGUSR3
-   static inline void ccxx_resume(cctid_t tid) { 
-	   pthread_kill(tid, CCXX_SIG_THREAD_RESUME); 
+   static inline void ccxx_resume(cctid_t tid) {
+	   pthread_kill(tid, CCXX_SIG_THREAD_RESUME);
    }
-   static inline void ccxx_suspend(cctid_t tid) { 
-	   pthread_kill(tid, CCXX_SIG_THREAD_SUSPEND); 
+   static inline void ccxx_suspend(cctid_t tid) {
+	   pthread_kill(tid, CCXX_SIG_THREAD_SUSPEND);
    }
 # endif
 #endif
@@ -176,9 +176,8 @@ Thread::Cancel Thread::enterCancel(void)
 	if(!th)
 		return cancelInitial;
 
-	Cancel old = th->_cancel;	
-	if(old != cancelDisabled && old != cancelImmediate)
-	{
+	Cancel old = th->_cancel;
+	if(old != cancelDisabled && old != cancelImmediate) {
 		th->setCancel(cancelImmediate);
 #ifdef	WIN32
 		Thread::yield();
@@ -197,8 +196,7 @@ void Thread::exitCancel(Cancel old)
 	if(!th)
 		return;
 
-	if(old != th->_cancel)
-	{
+	if(old != th->_cancel) {
 #ifndef	WIN32
 		pthread_testcancel();
 #endif
@@ -212,8 +210,7 @@ void Thread::suspend(void)
 		return;
 
 #ifdef WIN32
-	if (!priv->_active || !priv->_suspendEnable)
-	{
+	if (!priv->_active || !priv->_suspendEnable) {
 #ifdef	CCXX_EXCEPTIONS
 		if (Thread::getException() != throwNothing)
 			throw this;
@@ -260,8 +257,7 @@ void Thread::resume(void)
 		return;
 
 #ifdef WIN32
-	if (!priv->_active || !priv->_suspendEnable)
-	{
+	if (!priv->_active || !priv->_suspendEnable) {
 #ifdef	CCXX_EXCEPTIONS
 		if (Thread::getException() != throwNothing)
 			throw this;
@@ -282,8 +278,7 @@ void Thread::resume(void)
   || (CCXX_SUSPEND_MODE == CCXX_SUSPEND_MODE_ONE_SIGNAL)
 	int c;
 	if ( (c = --priv->_suspendcount) > 0) return;
-	if ( c < 0 ) 
-	{
+	if ( c < 0 ) {
 		++priv->_suspendcount;
 		return;
 	}
@@ -297,24 +292,21 @@ void Thread::join(void)
 {
 	bool detached = isDetached();
 	joinSem.wait();
-	if(detached)
-	{
+	if(detached) {
 		joinSem.post();
 		return;
 	}
 
 #ifdef	WIN32		// wait for real w32 thread to cleanup
 
-	if(priv->_hThread)
-	{
+	if(priv->_hThread) {
 		WaitForSingleObject(priv->_hThread, INFINITE);
 		::CloseHandle(priv->_hThread);
 		priv->_hThread = NULL;
-	}		
+	}
 
 #else			// make sure we cleanup exiting thread
-	if(priv->_jtid)
-	{
+	if(priv->_jtid) {
 		pthread_join(priv->_jtid, NULL);
 	}
 
@@ -333,8 +325,7 @@ inline RETSIGTYPE ThreadImpl::ThreadSigSuspend(int)
 
 	sigemptyset(&sigs);
 	sigaddset(&sigs, SIGUSR3);
-	while ( (getThread()->priv->_suspendcount) > 0)
-	{
+	while ( (getThread()->priv->_suspendcount) > 0) {
 #ifdef	HAVE_SIGWAIT2
 		int signo;
 		sigwait(&sigs, &signo);
@@ -363,8 +354,7 @@ void	Thread::setSuspend(Suspend mode)
 	sigemptyset(&mask);
 	sigaddset(&mask, CCXX_SIG_THREAD_SUSPEND);
 
-	switch(mode)
-	{
+	switch(mode) {
 	case suspendEnable:
 		pthread_sigmask(SIG_UNBLOCK, &mask, NULL);
 		return;
@@ -395,9 +385,9 @@ static	sigset_t *blocked_signals(sigset_t *sig)
 }
 #endif // ndef WIN32
 
-typedef enum ThreadType { 
-	threadTypeNormal=0, 
-	threadTypeMain, 
+typedef enum ThreadType {
+	threadTypeNormal=0,
+	threadTypeMain,
 	threadTypePosix,
 	threadTypeDummy
 } ThreadType;
@@ -472,9 +462,8 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeDummy))
 	DuplicateHandle(process,GetCurrentThread(),process,&priv->_hThread,0,FALSE,DUPLICATE_SAME_ACCESS);
 	_parent = this;
 	priv->_cancellation = CreateEvent(NULL, TRUE, FALSE, NULL);
-	
-	if(isMain)
-	{
+
+	if(isMain) {
 		setName("main()");
 		priv->_type   = threadTypeMain;
 		_main = this;
@@ -488,12 +477,11 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeDummy))
 	priv->_tid = pthread_self();
 	_parent = NULL;
 	struct sigaction act;
-	
+
 	// NOTE: for race condition (signal handler can use getThread)
 	// you should initialize _main and _self before registering signals
 	ThreadImpl::_self.setKey(this);
-	if(isMain == true)
-	{
+	if(isMain == true) {
 		_main = this;
 		priv->_type = threadTypeMain;
 #if !defined(__CYGWIN32__) && !defined(__MINGW32__)
@@ -517,7 +505,7 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeDummy))
 		sigaction(SIGPOLL, &act, NULL);
 # else
 		sigaction(SIGIO, &act, NULL);
-# endif		
+# endif
 
 # if CCXX_SUSPEND_MODE == CCXX_SUSPEND_MODE_ONE_SIGNAL
 		act.sa_handler = ccxx_sigsuspend;
@@ -542,17 +530,16 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeDummy))
 		sigaction(CCXX_SIG_THREAD_CANCEL, &act, NULL);
 # endif
 #endif
-    	}
+		}
 
 #endif // WIN32
-}	
+}
 
 Thread::Thread(int pri, size_t stack):
 _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 {
 #ifdef WIN32
-	if(!_main)
-	{
+	if(!_main) {
 		_self.setKey(NULL);
 		_main = this;
 		setName("main()");
@@ -569,7 +556,7 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 		priv->_throw = _parent->priv->_throw;
 	else
 		_parent = this;
-	
+
 	priv->_cancellation = CreateEvent(NULL, TRUE, FALSE, NULL);
 	if(!priv->_cancellation)
 		THROW(this);
@@ -587,8 +574,7 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 	if(Process::isRealtime() && pri < 0)
 		pri = 0;
 
-	switch(pri)
-	{
+	switch(pri) {
 	case 1:
 		priv->_priority = THREAD_PRIORITY_ABOVE_NORMAL;
 		break;
@@ -614,22 +600,19 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 #ifdef	PTHREAD_STACK_MIN
 	if(stack && stack <=  _autostack)
 		pthread_attr_setstacksize(&priv->_attr, _autostack);
-	else if(stack > _autostack)
-	{
+	else if(stack > _autostack) {
 		if(stack < PTHREAD_STACK_MIN)
 			stack = PTHREAD_STACK_MIN;
 		else	// align to nearest min boundry
-		{	
+		{
 			salign = stack / PTHREAD_STACK_MIN;
 			if(stack % PTHREAD_STACK_MIN)
 				++salign;
 			stack = salign * PTHREAD_STACK_MIN;
 		}
-		if(stack && pthread_attr_setstacksize(&priv->_attr, stack))
-		{
+		if(stack && pthread_attr_setstacksize(&priv->_attr, stack)) {
 #ifdef	CCXX_EXCEPTIONS
-			switch(Thread::getException())
-			{
+			switch(Thread::getException()) {
 			case throwObject:
 				throw(this);
 				return;
@@ -651,21 +634,18 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 #ifndef	__FreeBSD__
 #ifdef	_POSIX_THREAD_PRIORITY_SCHEDULING
 #ifdef HAVE_SCHED_GETSCHEDULER
-#define	__HAS_PRIORITY_SCHEDULING__	
+#define	__HAS_PRIORITY_SCHEDULING__
 	if(pri < 0 && Process::isRealtime())
 		pri = 0;
 
-	if(pri)
-	{
+	if(pri) {
 		struct sched_param sched;
 		int policy;
 
 		policy = sched_getscheduler(0);
-		if(policy < 0)
-		{
+		if(policy < 0) {
 #ifdef	CCXX_EXCEPTIONS
-			switch(Thread::getException())
-			{
+			switch(Thread::getException()) {
 			case throwObject:
 				throw(this);
 				return;
@@ -694,16 +674,16 @@ _cancel(cancelDefault), _start(NULL), priv(new ThreadImpl(threadTypeNormal))
 		sched.sched_priority = pri;
 		pthread_attr_setschedpolicy(&priv->_attr, policy);
 		pthread_attr_setschedparam(&priv->_attr, &sched);
-	}	
+	}
 #endif // ifdef HAVE_SCHED_GETSCHEDULER
 #endif // ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
 #endif // ifndef __FreeBSD__
 
 #ifdef	__HAS_PRIORITY_SCHEDULING__
 	if(!pri)
-	        pthread_attr_setinheritsched(&priv->_attr, PTHREAD_INHERIT_SCHED);             
+	        pthread_attr_setinheritsched(&priv->_attr, PTHREAD_INHERIT_SCHED);
 #else
-        pthread_attr_setinheritsched(&priv->_attr, PTHREAD_INHERIT_SCHED);             
+	pthread_attr_setinheritsched(&priv->_attr, PTHREAD_INHERIT_SCHED);
 #endif
 
 	_parent = getThread();
@@ -726,7 +706,7 @@ Thread::Thread(const Thread &th)
 	priv->_suspendEnable = false;
 
 	setName(NULL);
-	
+
 //	sigset_t mask, newmask;
 //	int rc;
 //
@@ -752,8 +732,7 @@ Thread::~Thread()
 		return;
 #endif
 
-	if(priv->_type == threadTypeDummy)
-	{
+	if(priv->_type == threadTypeDummy) {
 		delete priv;
 		priv = NULL;
 		return;
@@ -768,7 +747,7 @@ void Thread::setName(const char *text)
 		snprintf(_name, sizeof(_name), "%s", text);
 	else
 		snprintf(_name, sizeof(_name), "%ld", (long)getId());
-}	
+}
 
 void Thread::initial(void)
 {
@@ -801,19 +780,19 @@ bool Thread::isThread(void) const
 
 bool Thread::isDetached(void) const
 {
-        if(!priv)
-                return false;
+	if(!priv)
+		return false;
 
 #ifdef  WIN32
 	// win32 doesn't support detached threads directly
 	return priv->_detached;
 #else
-        int state;
+	int state;
 
-        pthread_attr_getdetachstate(&priv->_attr, &state);
-        if(state == PTHREAD_CREATE_DETACHED)
-                return true;
-        return false;
+	pthread_attr_getdetachstate(&priv->_attr, &state);
+	if(state == PTHREAD_CREATE_DETACHED)
+		return true;
+	return false;
 #endif
 }
 
@@ -848,8 +827,7 @@ int Thread::start(Semaphore *st)
 	_start = st;
 
 	priv->_hThread = (HANDLE)_beginthreadex(NULL, (unsigned)priv->_stack, (exec_t)&Execute, (void *)this, CREATE_SUSPENDED, (unsigned *)&priv->_tid);
-	if(!priv->_hThread)
- 	{
+	if(!priv->_hThread) {
 		CloseHandle(priv->_cancellation);
 		priv->_cancellation = NULL;
 		return -1;
@@ -866,10 +844,8 @@ int Thread::start(Semaphore *st)
 	return 0;
 
 #else
-	if(priv->_tid)
-	{
-		if(_start)
-		{
+	if(priv->_tid) {
+		if(_start) {
 			_start->post();
 			return 0;
 		}
@@ -886,7 +862,7 @@ int Thread::detach(Semaphore *st)
 {
 	_parent = NULL;
 #ifdef WIN32
-	// win32 we emulate detach	
+	// win32 we emulate detach
 	if(!priv)
 		return -1;
 	priv->_detached = true;
@@ -899,11 +875,9 @@ int Thread::detach(Semaphore *st)
 	if(!priv)
 		return -1;
 
-	if(priv->_tid)
-	{
+	if(priv->_tid) {
 		pthread_detach(priv->_tid);
-		if(_start)
-		{	
+		if(_start) {
 			_start->post();
 		        pthread_attr_setdetachstate(&priv->_attr, PTHREAD_CREATE_DETACHED);
 			return 0;
@@ -930,28 +904,25 @@ void Thread::terminate(void)
 
 	hThread = priv->_hThread;
 
-	if (!priv->_tid || isThread())
-	{
+	if (!priv->_tid || isThread()) {
 		if( priv->_cancellation)
 			::CloseHandle(priv->_cancellation);
-      		if(hThread)
-            		::CloseHandle(hThread);
+	  		if(hThread)
+					::CloseHandle(hThread);
 		delete priv;
 		priv = NULL;
-      		return;
+	  		return;
 	}
 
 	bool terminated = false;
-	if(!priv->_active && hThread != NULL)
-	{
+	if(!priv->_active && hThread != NULL) {
 		// NOTE: add a test in testthread for multiple
 		// suspended Terminate
 		ResumeThread(hThread);
 		TerminateThread(hThread, 0);
 		terminated = true;
 	}
-	else if(hThread != NULL)
-	{
+	else if(hThread != NULL) {
 		switch(_cancel)	{
 		case cancelImmediate:
 			TerminateThread(hThread, 0);
@@ -961,8 +932,7 @@ void Thread::terminate(void)
 			SetEvent(priv->_cancellation);
 		}
 	}
-	if(hThread != NULL)
-	{
+	if(hThread != NULL) {
 		WaitForSingleObject(hThread, INFINITE);
 		CloseHandle(hThread);
 		hThread = NULL;
@@ -985,33 +955,30 @@ void Thread::terminate(void)
 	if(!priv)
 		return;
 
-        cctid_t jtid = priv->_jtid, tid = priv->_tid;
+	cctid_t jtid = priv->_jtid, tid = priv->_tid;
 
-	if(jtid && (pthread_self() != jtid))
-	{
+	if(jtid && (pthread_self() != jtid)) {
 		pthread_join(jtid, NULL);
 		priv->_jtid = 0;
 	}
-	else if((pthread_self() != tid) && tid)
-	{
+	else if((pthread_self() != tid) && tid) {
 		// in suspend thread cannot be cancelled or signaled
 		// ??? rigth
 		// ccxx_resume(priv->_tid);
-		
+
 
 		// assure thread has ran before we try to cancel...
 		if(_start)
 			_start->post();
 
 		pthread_cancel(tid);
-		if(!isDetached())
-		{
+		if(!isDetached()) {
 			pthread_join(tid,NULL);
 			priv->_tid = 0;
 		}
 	}
 
-        pthread_attr_destroy(&priv->_attr);
+	pthread_attr_destroy(&priv->_attr);
 #endif
 	delete priv;
 	priv = NULL;
@@ -1028,8 +995,7 @@ void Thread::sync(void)
 
 void Thread::exit(void)
 {
-	if (isThread())
-	{
+	if (isThread()) {
 		setCancel(cancelDisabled);
 #ifdef WIN32
 		close();
@@ -1038,9 +1004,9 @@ void Thread::exit(void)
 		pthread_exit(NULL);
 #endif // WIN32
 	}
-	
+
 }
-		
+
 void Thread::close()
 {
 	bool detached = isDetached();
@@ -1052,7 +1018,7 @@ void Thread::close()
 	setCancel(cancelDisabled);
 //	if(_parent)
 //		_parent->notify(this);
-      
+
 	// final can call destructor (that call Terminate)
 	final();
 
@@ -1064,11 +1030,10 @@ void Thread::close()
 	if (ThreadImpl::_self.getKey() == this)
 #endif
 	{
-		if(priv)
-		{
+		if(priv) {
 #ifndef	WIN32
 			priv->_jtid = priv->_tid;
-#else			
+#else
 			priv->_active = false;
 #endif
 		}
@@ -1079,7 +1044,7 @@ void Thread::close()
 
 	if(detached)
 		delete this;
-}
+	}
 
 #ifndef WIN32
 inline void ThreadImpl::ThreadCleanup(Thread* th)
@@ -1087,19 +1052,19 @@ inline void ThreadImpl::ThreadCleanup(Thread* th)
 	// close thread
 	// (freddy77) Originally I thougth to throw an exception for deferred
 	// for capture it and cleanup using C++ destructor
-	// this doesn't work out!! 
+	// this doesn't work out!!
 	// Throwing exception here (in cleanup) core dump app
 	th->close();
-}
+	}
 
 extern "C" {
 
 static void ccxx_thread_cleanup(void* arg)
 {
 	ThreadImpl::ThreadCleanup( (Thread*)arg );
-}
+		}
 
-};
+	};
 
 inline void ThreadImpl::ThreadExecHandler(Thread *th)
 {
@@ -1117,8 +1082,7 @@ inline void ThreadImpl::ThreadExecHandler(Thread *th)
 	// using SIGUSR3 do not enable suspend by default
 	th->setSuspend(Thread::suspendEnable);
 	th->yield();
-	if(th->_start)
-	{
+	if(th->_start) {
 		th->_start->wait();
 		th->_start = NULL;
 	}
@@ -1135,7 +1099,7 @@ inline void ThreadImpl::ThreadExecHandler(Thread *th)
 		ThreadImpl::_self.setKey(NULL);
 	th->close();
 	pthread_exit(NULL);
-}
+	}
 
 // delete Thread class created for no CommonC++ thread
 inline void ThreadImpl::ThreadDestructor(Thread* th)
@@ -1146,21 +1110,21 @@ inline void ThreadImpl::ThreadDestructor(Thread* th)
 		return;
 	if (th->priv->_type == threadTypeDummy)
 		delete th;
-}
+	}
 
 extern "C" {
 
 static void ccxx_thread_destructor(void* arg)
 {
 	ThreadImpl::ThreadDestructor( (Thread*)arg );
-}
+		}
 
 static void ccxx_exec_handler(Thread *th)
 {
 	ThreadImpl::ThreadExecHandler(th);
-}
+		}
 
-};
+	};
 #endif // ndef WIN32
 
 #ifdef	CCXX_SIG_THREAD_CANCEL
@@ -1171,9 +1135,8 @@ void	Thread::setCancel(Cancel mode)
 
 	sigemptyset(&mask);
 	sigaddset(&mask, CCXX_SIG_THREAD_CANCEL);
-	
-	switch(mode)
-	{
+
+	switch(mode) {
 	case cancelImmediate:
 		pthread_sigmask(SIG_UNBLOCK, &mask, NULL);
 		break;
@@ -1184,14 +1147,13 @@ void	Thread::setCancel(Cancel mode)
 		break;
 	}
 	_cancel = mode;
-}
+	}
 #else
 
 void	Thread::setCancel(Cancel mode)
 {
 #ifdef WIN32
-	switch(mode)	
-	{
+	switch(mode) {
 	case cancelDeferred:
 	case cancelImmediate:
 		_cancel = mode;
@@ -1205,8 +1167,7 @@ void	Thread::setCancel(Cancel mode)
 #else
 	int old;
 
-	switch(mode)
-	{
+	switch(mode) {
 	case cancelImmediate:
 		pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, &old);
 		pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS, &old);
@@ -1224,7 +1185,7 @@ void	Thread::setCancel(Cancel mode)
 	}
 	_cancel = mode;
 #endif // WIN32
-}
+	}
 
 #endif
 
@@ -1241,7 +1202,7 @@ void	Thread::yield(void)
 	sigemptyset(&cancel);
 	sigaddset(&cancel, CCXX_SIG_THREAD_CANCEL);
 
-	if(th && th->_cancel != cancelDisabled && 
+	if(th && th->_cancel != cancelDisabled &&
 	   th->_cancel != cancelInitial)
 		pthread_sigmask(SIG_UNBLOCK, &cancel, &old);
 #else
@@ -1257,19 +1218,19 @@ void	Thread::yield(void)
 #endif
 
 #endif // WIN32
-}
+	}
 
 void Thread::setException(Thread::Throw mode)
 {
 	Thread *thread = getThread();
 	thread->priv->_throw = mode;
-}
+	}
 
 Thread::Throw Thread::getException(void)
 {
 	Thread *thread = getThread();
 	return thread->priv->_throw;
-}
+	}
 
 Cancellation::Cancellation(Thread::Cancel cancel)
 {
@@ -1279,7 +1240,7 @@ Cancellation::Cancellation(Thread::Cancel cancel)
 
 	prior = thread->getCancel();
 	thread->setCancel(cancel);
-}
+	}
 
 Cancellation::~Cancellation()
 {
@@ -1288,19 +1249,17 @@ Cancellation::~Cancellation()
 		return;
 
 	thread->setCancel(prior);
-}
+	}
 
 bool Thread::testCancel(void)
 {
 #ifdef WIN32
-	switch(_cancel)
-	{
+	switch(_cancel) {
 	case cancelInitial:
 	case cancelDisabled:
 		break;
 	default:
-		if(WaitForSingleObject(priv->_cancellation, 0) == WAIT_OBJECT_0)
-		{
+		if(WaitForSingleObject(priv->_cancellation, 0) == WAIT_OBJECT_0) {
 			if (_cancel == cancelManual)
 				THROW(InterruptException());
 			else
@@ -1312,33 +1271,33 @@ bool Thread::testCancel(void)
 #else // WIN32
 
 #ifdef  CCXX_SIG_THREAD_CANCEL
-        sigset_t cancel, old;
- 
-        sigemptyset(&cancel);
-        sigaddset(&cancel, CCXX_SIG_THREAD_CANCEL);
- 
-        if(_cancel != cancelDisabled &&
-           _cancel != cancelInitial)
-                pthread_sigmask(SIG_UNBLOCK, &cancel, &old);
+		sigset_t cancel, old;
+
+		sigemptyset(&cancel);
+		sigaddset(&cancel, CCXX_SIG_THREAD_CANCEL);
+
+		if(_cancel != cancelDisabled &&
+		   _cancel != cancelInitial)
+		pthread_sigmask(SIG_UNBLOCK, &cancel, &old);
 #else
-        pthread_testcancel();
+		pthread_testcancel();
 #endif
- 
+
 #ifdef  CCXX_SIG_THREAD_CANCEL
-        if(_cancel != cancelDisabled)
-                pthread_sigmask(SIG_SETMASK, &old, NULL);
+		if(_cancel != cancelDisabled)
+		pthread_sigmask(SIG_SETMASK, &old, NULL);
 #endif
 	return false;
 
 #endif // WIN32
-} 
+	}
 
 #ifdef WIN32
 
 bool Thread::isCancelled() const
 {
 	return waitThread(priv->_cancellation, 0) == WAIT_OBJECT_0;
-}
+	}
 
 DWORD Thread::waitThread(HANDLE hRef, timeout_t timeout)
 {
@@ -1348,35 +1307,32 @@ DWORD Thread::waitThread(HANDLE hRef, timeout_t timeout)
 		return th->waitHandle(hRef, timeout);
 	else
 		return WaitForSingleObject(hRef, timeout);
-}
+	}
 
-void Thread::sleep(timeout_t timeout) 
+void Thread::sleep(timeout_t timeout)
 {
 	Thread *th = getThread();
-	if(!th)
-	{
+	if(!th) {
 		SleepEx(timeout, FALSE);
 		return;
 	}
 
-	switch(th->_cancel)
-	{
+	switch(th->_cancel) {
 	case cancelInitial:
 	case cancelDisabled:
 		SleepEx(timeout, FALSE);
 		break;
 	default:
-		if(WaitForSingleObject(th->priv->_cancellation, timeout) == WAIT_OBJECT_0)
-		{
+		if(WaitForSingleObject(th->priv->_cancellation, timeout) == WAIT_OBJECT_0) {
 			if (th->_cancel == cancelManual)
 				THROW(InterruptException());
 			else
 				th->exit();
 		}
 	}
-}
+	}
 
-DWORD Thread::waitHandle(HANDLE obj, timeout_t timeout) 
+DWORD Thread::waitHandle(HANDLE obj, timeout_t timeout)
 {
 	HANDLE objects[2];
 	DWORD stat;
@@ -1385,8 +1341,7 @@ DWORD Thread::waitHandle(HANDLE obj, timeout_t timeout)
 	objects[1] = obj;
 
 	// FIXME: what should happen if someone enable cancellation on wait??
-	switch(_cancel)
-	{
+	switch(_cancel) {
 	case cancelInitial:
 	case cancelDisabled:
 		return WaitForSingleObject(obj, timeout);
@@ -1403,24 +1358,23 @@ DWORD Thread::waitHandle(HANDLE obj, timeout_t timeout)
 			return stat;
 		}
 	}
-}
+	}
 
 // Entry point linked for default disable thread call, not suitable
 // for threading library...
 BOOL WINAPI DllMain(
-        HANDLE  hDllHandle,
-        DWORD   dwReason,
-        LPVOID  lpreserved
-        )
+	HANDLE  hDllHandle,
+	DWORD   dwReason,
+	LPVOID  lpreserved
+	)
 {
-	switch(dwReason)
-	{
+	switch(dwReason) {
 	case DLL_THREAD_DETACH:
 		DummyThread::CheckDelete();
 		break;
 	}
-        return TRUE ;
-}
+		return TRUE ;
+	}
 
 #endif // WIN32
 
@@ -1428,10 +1382,9 @@ BOOL WINAPI DllMain(
 Thread *Thread::get(void)
 {
 	Thread *thread;
-	
+
 	// fix strange no-init on Solaris
-        if(!Thread::_main)
-	{
+		if(!Thread::_main) {
 		new (&_mainthread) MainThread();
 		return &_mainthread;
 	}
@@ -1442,14 +1395,13 @@ Thread *Thread::get(void)
 	if (thread == DUMMY_INVALID_THREAD)
 		return NULL;
 
-	if(!thread)
-	{
+	if(!thread) {
 		// this Thread will be deleted by ccxx_thread_destruct
 		thread = new DummyThread;
 		ThreadImpl::_self.setKey(thread);
 	}
 	return thread;
-}
+	}
 
 #else // WIN32
 
@@ -1461,26 +1413,24 @@ Thread *Thread::get(void)
 	if (!th)
 		th = new DummyThread();
 	return th;
-}
+	}
 
 unsigned __stdcall Thread::Execute(Thread *th)
 {
 	_self.setKey(th);
 	th->yield();
 
-	if(th->_start)
-	{
+	if(th->_start) {
 		th->_start->wait();
 		th->_start = NULL;
 	}
 
-	try
-	{
+	try {
 		th->priv->_tid = GetCurrentThreadId();
 		if(!th->_name[0])
 			snprintf(th->_name, sizeof(th->_name), "%d", GetCurrentThreadId());
 		th->initial();
-		if(th->getCancel() == cancelInitial) 
+		if(th->getCancel() == cancelInitial)
 			th->setCancel(cancelDefault);
 		th->run();
 	}
@@ -1490,7 +1440,7 @@ unsigned __stdcall Thread::Execute(Thread *th)
 
 	th->close();
 	return 0;
-}
+	}
 #endif //WIN32
 
 #if !defined(WIN32)
@@ -1505,13 +1455,12 @@ inline void ThreadImpl::PosixThreadSigHandler(int signo)
 #ifdef	CCXX_EXCEPTIONS
 	if (t) th = dynamic_cast<PosixThread*>(t);
 #else
-        if (t) th = (PosixThread*)(t);
+		if (t) th = (PosixThread*)(t);
 #endif
 
 	if (!th) return;
 
-	switch(signo)
-	{
+	switch(signo) {
 	case SIGHUP:
 		if(th)
 			th->onHangup();
@@ -1526,13 +1475,12 @@ inline void ThreadImpl::PosixThreadSigHandler(int signo)
 		break;
 	case SIGALRM:
 #ifndef	CCXX_SIG_THREAD_ALARM
-		if(PosixThread::_timer)
-		{
+		if(PosixThread::_timer) {
 			PosixThread::_timer->_alarm = 0;
 			PosixThread::_timer->onTimer();
 		}
 		else
-#endif 
+#endif
 		    if(th)
 			th->onTimer();
 		break;
@@ -1548,46 +1496,45 @@ inline void ThreadImpl::PosixThreadSigHandler(int signo)
 		if(th)
 			th->onSignal(signo);
 	}
-}
+	}
 
 extern "C" {
 
 static void ccxx_sig_handler(int signo)
 {
 	ThreadImpl::PosixThreadSigHandler(signo);
-}
+		}
 
-};
+	};
 
 PosixThread::PosixThread(int pri, size_t stack):
-	Thread(pri,stack)
-{
-       SysTime::getTime(&_alarm);
-}
+	Thread(pri,stack) {
+	   SysTime::getTime(&_alarm);
+	}
 
 void PosixThread::onTimer(void)
 {
-}
+	}
 
 void PosixThread::onHangup(void)
 {
-}
+	}
 
 void PosixThread::onException(void)
 {
-}
+	}
 
 void PosixThread::onDisconnect(void)
 {
-}
+	}
 
 void PosixThread::onPolling(void)
 {
-}
+	}
 
 void PosixThread::onSignal(int sig)
 {
-}
+	}
 
 
 void PosixThread::setTimer(timeout_t timer, bool periodic)
@@ -1596,7 +1543,7 @@ void PosixThread::setTimer(timeout_t timer, bool periodic)
 
 #ifdef	HAVE_SETITIMER
 	struct itimerval itimer;
-	
+
 	memset(&itimer, 0, sizeof(itimer));
 	itimer.it_value.tv_usec = (timer * 1000) % 1000000;
 	itimer.it_value.tv_sec = timer / 1000;
@@ -1608,11 +1555,11 @@ void PosixThread::setTimer(timeout_t timer, bool periodic)
 	timer /= 1000;
 #endif
 
-#ifndef	CCXX_SIG_THREAD_ALARM	
+#ifndef	CCXX_SIG_THREAD_ALARM
 	_arm.enterMutex();
 	_timer = this;
 #endif
-       SysTime::getTime(&_alarm);
+	   SysTime::getTime(&_alarm);
 	sigemptyset(&sigs);
 	sigaddset(&sigs, SIGALRM);
 	pthread_sigmask(SIG_UNBLOCK, &sigs, NULL);
@@ -1621,7 +1568,7 @@ void PosixThread::setTimer(timeout_t timer, bool periodic)
 #else
 	alarm(timer);
 #endif
-}	
+	}
 
 timeout_t PosixThread::getTimer(void) const
 {
@@ -1640,7 +1587,7 @@ timeout_t PosixThread::getTimer(void) const
 	time_t now = SysTime::getTime();
 	return (timeout_t)(((now - _alarm) * 1000) + 500);
 #endif
-}
+	}
 
 void PosixThread::endTimer(void)
 {
@@ -1666,7 +1613,7 @@ void PosixThread::endTimer(void)
 	_arm.leaveMutex();
 	_timer = NULL;
 #endif
-}
+	}
 
 #if defined(HAVE_SIGWAIT) || defined(HAVE_SIGWAIT2)
 void	PosixThread::waitSignal(signo_t signo)
@@ -1680,7 +1627,7 @@ void	PosixThread::waitSignal(signo_t signo)
 #else
 	sigwait(&mask, &signo);
 #endif
-}
+	}
 #endif // ifdef HAVE_SIGWAIT
 
 void	PosixThread::setSignal(int signo, bool mode)
@@ -1694,27 +1641,27 @@ void	PosixThread::setSignal(int signo, bool mode)
 		pthread_sigmask(SIG_UNBLOCK, &sigs, NULL);
 	else
 		pthread_sigmask(SIG_BLOCK, &sigs, NULL);
-}	
+	}
 
 void	PosixThread::signalThread(Thread* th,signo_t signo)
 {
 	pthread_kill(th->priv->_tid, signo);
-}
+	}
 
 pthread_attr_t * PosixThread::getPthreadAttrPtr(void)
 {
  	return &priv->_attr;
-}
+	}
 
 pthread_t PosixThread::getPthreadId(void)
 {
 	return priv->_tid;
-}
+	}
 
 void PosixThread::sigInstall(int signo)
 {
 	struct sigaction act;
-	
+
 	act.sa_handler = (signalexec_t)&ccxx_sig_handler;
 	sigemptyset(&act.sa_mask);
 
@@ -1724,7 +1671,7 @@ void PosixThread::sigInstall(int signo)
 	act.sa_flags = 0;
 #endif
 	sigaction(signo, &act, NULL);
-}
+	}
 #endif
 
 #ifdef	USE_POLL
@@ -1733,100 +1680,98 @@ Poller::Poller()
 {
 	nufds = 0;
 	ufds = NULL;
-}
+	}
 
 Poller::~Poller()
 {
-	if(ufds)
-	{
+	if(ufds) {
 		delete[] ufds;
 		ufds = NULL;
 	}
-}
+	}
 
 pollfd *Poller::getList(int cnt)
 {
-	if(nufds < cnt)
-	{
+	if(nufds < cnt) {
 		if(ufds)
 			delete[] ufds;
 		ufds = new pollfd[cnt];
 		nufds = cnt;
 	}
 	return ufds;
-}
+	}
 
 #endif
 
 Mutex SysTime::timeLock;
 
-time_t SysTime::getTime(time_t *tloc) 
+time_t SysTime::getTime(time_t *tloc)
 {
-    time_t ret;
-    lock();
-    time_t temp;
+	time_t ret;
+	lock();
+	time_t temp;
 #ifdef	WIN32
-    ::time(&temp);
+	::time(&temp);
 #else
-    std::time(&temp);
+	std::time(&temp);
 #endif
-    memcpy(&ret, &temp, sizeof(time_t));
-    if (tloc != NULL) 
-        memcpy(tloc, &ret, sizeof(time_t));
-    unlock();
-    return ret;   
-}
+	memcpy(&ret, &temp, sizeof(time_t));
+	if (tloc != NULL)
+		memcpy(tloc, &ret, sizeof(time_t));
+	unlock();
+	return ret;
+	}
 
-int SysTime::getTimeOfDay(struct timeval *tp) 
+int SysTime::getTimeOfDay(struct timeval *tp)
 {
 	struct timeval temp;
-    int ret(0);
-    lock();
+	int ret(0);
+	lock();
 
 #ifdef	WIN32
-    // We could use _ftime(), but it is not available on WinCE.
-    // (WinCE also lacks time.h)
-    // Note also that the average error of _ftime is around 20 ms :)
-    time_t now;
-    time(&now);
-    temp.tv_sec = (long)now;
-    temp.tv_usec = (GetTickCount() % 1000) * 1000;
+	// We could use _ftime(), but it is not available on WinCE.
+	// (WinCE also lacks time.h)
+	// Note also that the average error of _ftime is around 20 ms :)
+	time_t now;
+	time(&now);
+	temp.tv_sec = (long)now;
+	temp.tv_usec = (GetTickCount() % 1000) * 1000;
 	memcpy(tp, &temp, sizeof(struct timeval));
 #else
-    ret = ::gettimeofday(&temp, NULL);
-    if (ret == 0) 
-        memcpy(tp, &temp, sizeof(struct timeval));
+	ret = ::gettimeofday(&temp, NULL);
+	if(ret == 0)
+		memcpy(tp, &temp, sizeof(struct timeval));
 #endif
 
-    unlock();
-    return ret;
-}
+	unlock();
+	return ret;
+	}
 
-struct tm *SysTime::getLocalTime(const time_t *clock, struct tm* result) 
+struct tm *SysTime::getLocalTime(const time_t *clock, struct tm* result)
 {
-    lock();
+	lock();
 #ifdef	WIN32
-    struct tm *temp = ::localtime(clock);
+	struct tm *temp = ::localtime(clock);
 #else
-    struct tm *temp = std::localtime(clock);
+	struct tm *temp = std::localtime(clock);
 #endif
-    memcpy(result, temp, sizeof(struct tm));
-    unlock();
+	memcpy(result, temp, sizeof(struct tm));
+	unlock();
 	return result;
-}
+	}
 
-struct tm *SysTime::getGMTTime(const time_t *clock, struct tm* result) 
+struct tm *SysTime::getGMTTime(const time_t *clock, struct tm* result)
 {
-    lock();
+	lock();
 #ifdef	WIN32
-    struct tm *temp = ::gmtime(clock);
+	struct tm *temp = ::gmtime(clock);
 #else
-    struct tm *temp = std::gmtime(clock);
+	struct tm *temp = std::gmtime(clock);
 #endif
-    memcpy(result, temp, sizeof(struct tm));
-    unlock();
+	memcpy(result, temp, sizeof(struct tm));
+	unlock();
 	return result;
-}
+	}
 
 // C stuff
 // this function must declared as extern "C" for some compiler
@@ -1834,7 +1779,7 @@ struct tm *SysTime::getGMTTime(const time_t *clock, struct tm* result)
 #ifdef CCXX_NAMESPACES
 }
 #endif
- 
+
 /** EMACS **
  * Local variables:
  * mode: c++
