@@ -19,9 +19,9 @@
 // templates or use macros or inline functions from this file, or you compile
 // this file and link it with other files to produce an executable, this
 // file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however    
+// the GNU General Public License.  This exception does not however
 // invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.    
+// the GNU General Public License.
 //
 // This exception applies only to the code released under the name GNU
 // Common C++.  If you copy code from other releases into a copy of GNU
@@ -80,10 +80,9 @@ static bool isElement(char c)
 void XMLStream::putData(char c)
 {
 	dbuf[dp++] = c;
-	if(dp >= sizeof(dbuf))
-	{
+	if(dp >= sizeof(dbuf)) {
 		if(ecount)
-			characters((unsigned char *)dbuf, dp);		
+			characters((unsigned char *)dbuf, dp);
 		dp = 0;
 	}
 }
@@ -111,10 +110,8 @@ bool XMLStream::parseTag(void)
 	unsigned attr = 0;
 	char *ep;
 
-	if(*data == '/')
-	{
-		while(--len)
-		{
+	if(*data == '/') {
+		while(--len) {
 			if(!isElement(*(++data)))
 				break;
 		}
@@ -128,50 +125,42 @@ bool XMLStream::parseTag(void)
 		if(ecount < 0)
 			return false;
 		if(!ecount)
-			endDocument();	
+			endDocument();
 	}
-	else if(*data == '!')
-	{
+	else if(*data == '!') {
 		dp = 0;
 		return true; // dtd
 	}
-	else if(*data == '?')
-	{
-		if(!strnicmp(data, "?xml version=\"", 14))
-		{
+	else if(*data == '?') {
+		if(!strnicmp(data, "?xml version=\"", 14)) {
 			// version info
 		}
 		dp = 0;
 	}
 	else if(!isElement(*data))
 		return false;
-	else
-	{
+	else {
 		end = false;
-		if(dbuf[dp - 1] == '/')
-		{
+		if(dbuf[dp - 1] == '/') {
 			--dp;
 			end = true;
 		}
 		len = 0;
 		data = dbuf;
-		while(len < dp)
-		{
+		while(len < dp) {
 			if(!isElement(*data))
 				break;
 			++len;
 			++data;
 		}
-		if(len == dp)
-		{
+		if(len == dp) {
 			if(!ecount)
 				startDocument();
 			++ecount;
 			attrib[0] = attrib[1] = NULL;
 			dbuf[dp] = 0;
 			startElement((const unsigned char *)dbuf, attrib);
-			if(end)
-			{
+			if(end) {
 ending:
 				--ecount;
 				endElement((const unsigned char *)dbuf);
@@ -187,10 +176,8 @@ ending:
 
 		// attributes, name is between data and len
 
-		for(;;)
-		{
-			while(!isElement(dbuf[len]) && len < dp)
-			{
+		for(;;) {
+			while(!isElement(dbuf[len]) && len < dp) {
 				if(!isspace(dbuf[len]))
 					return false;
 				dbuf[len++] = 0;
@@ -200,7 +187,7 @@ ending:
 				break;
 
 			attrib[attr++] = (const unsigned char *)(dbuf + len);
-			while(isElement(dbuf[len]) && len < dp)
+			while(len < dp && isElement(dbuf[len]))
 				++len;
 
 			if(len == dp)
@@ -208,21 +195,18 @@ ending:
 
 			if(dbuf[len] != '=')
 				return false;
-	
+
 			dbuf[len++] = 0;
-			if(len == dp)
-			{
+			if(len == dp) {
 				attrib[attr++] = (const unsigned char *)"";
 				break;
-			}	
+			}
 
-			if(isspace(dbuf[len]))
-			{
+			if(isspace(dbuf[len])) {
 				attrib[attr++] = (const unsigned char *)"";
 				continue;
 			}
-			if(dbuf[len] == '\'' || dbuf[len] == '\"')
-			{
+			if(dbuf[len] == '\'' || dbuf[len] == '\"') {
 				ep = strchr(dbuf + len + 1, dbuf[len]);
 				if(!ep)
 					return false;
@@ -235,9 +219,8 @@ ending:
 				return false;
 			attrib[attr++] = (const unsigned char *)dbuf;
 			while(isElement(dbuf[len]) && len < dp)
-				++len;	
-			if(len == dp)
-			{
+				++len;
+			if(len == dp) {
 				dbuf[len] = 0;
 				break;
 			}
@@ -250,20 +233,17 @@ ending:
 			goto ending;
 		dp = 0;
 		return true;
-	}							
+	}
 	return true;
 }
 
 bool XMLStream::parseChunk(const char *data, size_t len)
 {
 	unsigned char cp;
-	while(len--)
-	{
-		switch(state)
-		{
+	while(len--) {
+		switch(state) {
 		case AMP:
-			if((!dp && *data == '#') || isElement(*data))
-			{
+			if((!dp && *data == '#') || isElement(*data)) {
 				dbuf[dp++] = *data;
 				break;
 			}
@@ -287,25 +267,21 @@ bool XMLStream::parseChunk(const char *data, size_t len)
 			characters(&cp, 1);
 			dp = 0;
 			state = NONE;
-			break;	
+			break;
 		case TAG:
-			if(*data == '>')
-			{
+			if(*data == '>') {
 				state = NONE;
 				if(!parseTag())
 					return false;
 			}
-			else if(*data == '[' && dp == 7 && !strncmp(dbuf, "![CDATA", 7))
-			{
+			else if(*data == '[' && dp == 7 && !strncmp(dbuf, "![CDATA", 7)) {
 				state = CDATA;
 			}
-			else if(*data == '-' && dp == 2 && !strncmp(dbuf, "!-", 2))
-			{
+			else if(*data == '-' && dp == 2 && !strncmp(dbuf, "!-", 2)) {
 				state = COMMENT;
 				dp = 0;
 			}
-			else if(*data == '[' && !strncmp(dbuf, "!DOCTYPE ", 9)) 		
-			{
+			else if(*data == '[' && !strncmp(dbuf, "!DOCTYPE ", 9)) {
 				state = DTD;
 				dp = 0;
 			}
@@ -313,19 +289,16 @@ bool XMLStream::parseChunk(const char *data, size_t len)
 				putData(*data);
 			break;
 		case COMMENT:
-			if(*data == '>' && dp >= 2 && !strncmp(&dbuf[dp - 2], "--", 2))
-			{
+			if(*data == '>' && dp >= 2 && !strncmp(&dbuf[dp - 2], "--", 2)) {
 				dp -= 2;
 				if(dp)
 					comment((unsigned char *)dbuf, dp);
 				dp = 0;
 				state = NONE;
 			}
-			else
-			{
+			else {
 				dbuf[dp++] = *data;
-				if(dp == sizeof(dbuf))
-				{
+				if(dp == sizeof(dbuf)) {
 					comment((unsigned char *)dbuf, dp);
 					dp = 0;
 				}
@@ -334,13 +307,12 @@ bool XMLStream::parseChunk(const char *data, size_t len)
 		case CDATA:
 			putData(*data);
 			if(dp > 2)
-				if(!strcmp(&dbuf[dp - 3], "]]>"))
-				{
+				if(!strcmp(&dbuf[dp - 3], "]]>")) {
 					dp -= 3;
 					state = NONE;
 					clrData();
 				}
-			break;	
+			break;
 		case DTD:
 			if(*data == '<')
 				++dcount;
@@ -350,21 +322,19 @@ bool XMLStream::parseChunk(const char *data, size_t len)
 				state = NONE;
 			break;
 		case NONE:
-			if(*data == '<')
-			{
+			if(*data == '<') {
 				clrData();
 				state = TAG;
 			}
-			else if(ecount && *data == '&')
-			{
+			else if(ecount && *data == '&') {
 				clrData();
 				state = AMP;
 			}
 			else if(ecount)
 				putData(*data);
-		}	
+		}
 		++data;
-	}	
+	}
 	return true;
 }
 
@@ -583,7 +553,7 @@ void XMLRPC::begArray(void)
 #endif
 
 	if(fault) //do not include arrays in fault responses.
-		return; 
+		return;
 
 	if(!array)
 		strBuf << "<param>";
@@ -647,8 +617,7 @@ bool XMLRPC::send(const char *resource)
 #endif
 
 	endStruct();
-	while(array)
-	{
+	while(array) {
 		strBuf << "</data></array>" << endl;
 		--array;
 	}
